@@ -75,7 +75,7 @@ static int converse(	pam_handle_t *pamh,
 	int retval;
 	struct pam_conv *conv;
 
-	retval = pam_get_item(	pamh, PAM_CONV,  (const void **) &conv ) ; 
+	retval = my_pam_get_item(pamh, PAM_CONV, &conv); 
 	if ( retval == PAM_SUCCESS )
 		{
 	  		retval = conv->conv( 	nargs,  
