@@ -26,14 +26,13 @@
 		Added license.
  */
 
-#include "config.h"
-
 #include <unistd.h>
 #include <stdlib.h>
 #include <ctype.h>
 #include <wchar.h>
+#include <string.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 #include <ncp/nwnet.h>
@@ -62,15 +61,15 @@ help(void)
 int main(int argc, char *argv[]) {
 	NWDSCCODE dserr;
 	NWDSContextHandle ctx;
-	char* objectname = "[Root]";
-	char* context = "OrgUnit.Org.Country";
+	const char* objectname = "[Root]";
+	const char* context = "OrgUnit.Org.Country";
 	char canoned[1000];
 	int opt;
 	u_int32_t ctxflag = 0;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
