@@ -28,8 +28,6 @@
  */
 
 #define MAKE_NCPLIB
-#include "config.h"
-
 #include <ncp/nwcalls.h>
 #include <ncp/nwnet.h>
 #include "ncplib_i.h"
@@ -41,7 +39,7 @@
 #include <errno.h>
 #include <string.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -125,8 +123,8 @@ int main(int argc, char *argv[]) {
 	const char* sstr = "\xFF*";
 		
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
