@@ -31,7 +31,7 @@
   
  */
 
-#include "config.h"
+#define MAKE_NCPLIB
 
 #include <ncp/nwcalls.h>
 #include <ncp/nwnet.h>
@@ -42,7 +42,7 @@
 #include <wchar.h>
 #include <string.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -67,7 +67,7 @@ help(void)
 	       "\n"));
 }
 			
-void printstruct2(u_int32_t rim, struct nw_info_struct2* info) {
+static void printstruct2(u_int32_t rim, struct nw_info_struct2* info) {
 	if (rim & RIM_SPACE_ALLOCATED) {
 		printf("Space Allocated:       %08LX (%Ld)\n", info->SpaceAllocated,
 							      info->SpaceAllocated);
@@ -76,7 +76,7 @@ void printstruct2(u_int32_t rim, struct nw_info_struct2* info) {
 		printf("Attributes:            %08X\n", info->Attributes.Attributes);
 		printf("Flags:                 %04X\n", info->Attributes.Flags);
 	}
-	if (rim & RIM_DATA_SIZE) {
+	if (rim & (RIM_DATA_SIZE | RIM_SIZE64)) {
 		printf("Data Size:             %08LX (%Ld)\n", info->DataSize,
 							     info->DataSize);
 	}
@@ -161,12 +161,72 @@ void printstruct2(u_int32_t rim, struct nw_info_struct2* info) {
 		printf("Create Time:           %08X\n", info->MacTimes.CreateTime);
 		printf("Backup Time:           %08X\n", info->MacTimes.BackupTime);
 	}
+	if (rim & RIM_UNKNOWN25) {
+		printf("Unknown25:             %04X\n", info->Unknown25);
+	}
 	if (rim & RIM_NAME) {
 		printf("Name:                  ");
 		fwrite(info->Name.Name, 1, info->Name.NameLength, stdout);
 		printf("\n");
 	}
 }								    
+
+static int
+ncp_add_handle_path2(u_int8_t* buf,
+		     u_int8_t vol_num,
+		     u_int32_t dir_base, int dir_style,
+		     const unsigned char *encpath, int pathlen)
+{
+	buf[0] = vol_num;
+	buf[1] = dir_base;
+	buf[2] = dir_base >> 8;
+	buf[3] = dir_base >> 16;
+	buf[4] = dir_base >> 24;
+	buf[5] = dir_style;	
+	if (encpath) {
+		memcpy(buf + 6, encpath, pathlen);
+		return 6 + pathlen;
+	} else {
+		buf[6] = 0;
+		return 7;
+	}
+}
+
+static NWCCODE ncp_ns_obtain_entry_info_raw(struct ncp_conn *conn,
+			 unsigned int source_ns,
+			 unsigned int search_attribs,
+			 int dir_style,
+			 unsigned int vol, 
+			 u_int32_t dirent, 
+			 const unsigned char *encpath, size_t pathlen, 
+			 unsigned int target_ns,
+			 u_int32_t rim,
+			 /* struct nw_info_struct2 */ void *target, size_t sizeoftarget)
+{
+	NWCCODE result;
+	NW_FRAGMENT rp;
+	u_int8_t rqb[1000];
+	size_t rqlen;
+	
+	rp.fragAddress = target;
+	rp.fragSize = sizeoftarget;
+	
+	rqb[0] = 6;
+	rqb[1] = source_ns;
+	rqb[2] = target_ns;
+	rqb[3] = search_attribs;
+	rqb[4] = search_attribs >> 8;
+	rqb[5] = rim;
+	rqb[6] = rim >> 8;
+	rqb[7] = rim >> 16;
+	rqb[8] = rim >> 24;	
+
+	rqlen = ncp_add_handle_path2(rqb + 9, vol, dirent, dir_style, encpath, pathlen) + 9;
+	
+	result = NWRequestSimple(conn, 87, rqb, rqlen, &rp);
+	return result;
+}
+
 						      
 int main(int argc, char *argv[]) {
 	NWDSCCODE dserr;
@@ -180,17 +240,18 @@ int main(int argc, char *argv[]) {
 	u_int32_t destns = NW_NS_DOS;
 	u_int32_t searchattr = 0x8006;
 	char* s = NULL;
+	int doraw = 0;
 	
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
 	NWCallsInit(NULL, NULL);
 //	NWDSInitRequester();
 
-	while ((opt = getopt(argc, argv, "h?r:n:s:p:")) != EOF)
+	while ((opt = getopt(argc, argv, "h?r:n:s:p:R")) != EOF)
 	{
 		switch (opt)
 		{
@@ -206,6 +267,9 @@ int main(int argc, char *argv[]) {
 		case 'p':
 			s = optarg;
 			break;
+		case 'R':
+			doraw = 1;
+			break;
 		case 'h':
 		case '?':
 			help();
@@ -236,14 +300,33 @@ int main(int argc, char *argv[]) {
 		struct nw_info_struct2 iii;
 
 		memset(&iii, 0xCC, sizeof(iii));
-		dserr = ncp_ns_obtain_entry_info(conn,
-			NW_NS_DOS, searchattr,
-			0xFF, 0, 0, buffer, len, destns, rim, &iii, sizeof(iii));
-		if (dserr) {
-			fprintf(stderr, "Cannot obtain info: %s\n",
-				strnwerror(dserr));
+		
+		if (doraw) {
+			dserr = ncp_ns_obtain_entry_info_raw(conn,
+				NW_NS_DOS, searchattr,
+				0xFF, 0, 0, buffer, len, destns, rim, &iii, sizeof(iii));
+			if (dserr) {
+				fprintf(stderr, "Cannot obtain info: %s\n",
+					strnwerror(dserr));
+			} else {
+				size_t i;
+				unsigned char* p = (unsigned char*)&iii;
+				
+				for (i = 0; i < sizeof(iii); i++) {
+					printf("%02X ", p[i]);
+				}
+				printf("\n");
+			}
 		} else {
-			printstruct2(rim, &iii);
+			dserr = ncp_ns_obtain_entry_info(conn,
+				NW_NS_DOS, searchattr,
+				0xFF, 0, 0, buffer, len, destns, rim, &iii, sizeof(iii));
+			if (dserr) {
+				fprintf(stderr, "Cannot obtain info: %s\n",
+					strnwerror(dserr));
+			} else {
+				printstruct2(rim, &iii);
+			}
 		}
 	}
 	ncp_close(conn);
