@@ -27,8 +27,6 @@
 
  */
 
-#include "config.h"
-
 #include <ncp/nwcalls.h>
 #include <ncp/nwnet.h>
 
@@ -39,7 +37,7 @@
 #include <errno.h>
 #include <string.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -96,8 +94,8 @@ int main(int argc, char *argv[]) {
 	int myflag_val = 0;
 	
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
