@@ -27,8 +27,6 @@
 
  */
 
-#include "config.h"
-
 #include <ncp/nwcalls.h>
 #include <ncp/nwnet.h>
 
@@ -39,7 +37,7 @@
 #include <errno.h>
 #include <string.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -63,7 +61,7 @@ help(void)
 	       "\n"));
 }
 			
-void printstruct2(struct ncp_namespace_format* info) {
+static void printstruct2(struct ncp_namespace_format* info) {
 	int i;
 	
 	printf("Bits: Fixed:    %08X, count %d\n", info->BitMask.fixed,    info->BitsDefined.fixed);
@@ -106,8 +104,8 @@ int main(int argc, char *argv[]) {
 	u_int32_t mask = ~0;
 	
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
