@@ -31,8 +31,6 @@
 
  */
 
-#include "config.h"
-
 #include <ncp/nwcalls.h>
 #include <ncp/nwnet.h>
 
@@ -40,8 +38,9 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <wchar.h>
+#include <string.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -59,13 +58,15 @@ help(void)
 	         "usage: %s [options]\n"), progname);
 	printf(_("\n"
 	       "-h              Print this help text\n"
+	       "-S server       Server\n"
+	       "-f flag         Resolve flags\n"
 	       "-v value        Context DCK_FLAGS value\n"
 	       "-o object_name  Name of object\n"
 	       "-c context_name Name of current context\n"
 	       "\n"));
 }
 
-int dumpSAddr(unsigned char* buff, size_t l, size_t* pos) {
+static int dumpSAddr(unsigned char* buff, size_t l, size_t* pos) {
 	u_int32_t val;
 	size_t x = *pos;
 	
@@ -122,10 +123,10 @@ int main(int argc, char *argv[]) {
 	NWDSCCODE dserr;
 	NWDSContextHandle ctx;
 	NWCONN_HANDLE conn;
-	char* objectname = "[Root]";
-	char* context = "OrgUnit.Org.Country";
+	const char* objectname = "[Root]";
+	const char* context = "OrgUnit.Org.Country";
 	unsigned char* buff;
-	char* server = "CDROM";
+	const char* server = "CDROM";
 	int opt;
 	int stop = 1;
 	u_int32_t ctxflag = 0;
@@ -136,8 +137,8 @@ int main(int argc, char *argv[]) {
 	size_t l;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
@@ -276,6 +277,25 @@ lll:;
 			printf("Unknown: %08X\n", val);
 			if (dumpSAddr(buff, l, &x))
 				goto dump;
+		} else if (val == 3) {
+			printf("(alias)\n");
+			if (l < x + 4) {
+				printf("end of buffer\n");
+				goto dump;
+			}
+			val = DVAL_LH(buff, x);
+			x += 4;
+			printf("Aliased Object (%u bytes): ", val);
+			if (l < x + val) {
+				printf("end of buffer\n");
+				goto dump;
+			}
+			while (val > 1) {
+				printf("%c", BVAL(buff, x));
+				x += 2;
+				val -= 2;
+			}
+			printf("\n");
 		} else if (val == 4) {
 			printf("(referrals)\n");
 			if (l < x + 4) {
