@@ -25,9 +25,10 @@
 	1.00  1999, November 20		Petr Vandrovec <vandrove@vc.cvut.cz>
 		Added license.
 
- */
+	1.01  2001, June 10		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Remove some compilation warnings.
 
-#include "config.h"
+ */
 
 #include <ncp/nwcalls.h>
 #include <ncp/nwnet.h>
@@ -36,8 +37,9 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <wchar.h>
+#include <string.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -63,66 +65,13 @@ help(void)
 	       "\n"));
 }
 
-int dumpSAddr(unsigned char* buff, size_t l, size_t* pos) {
-	u_int32_t val;
-	size_t x = *pos;
-	
-	if (l < x + 4) {
-		goto dump;
-	}
-	val = DVAL_LH(buff, x);
-	x += 4;
-	printf("Server addresses: %d\n", val);
-	while (val-- > 0) {
-		u_int32_t type;
-		u_int32_t lskip;
-				
-		if (l < x + 4) {
-			goto dump;
-		}
-		type = DVAL_LH(buff, x);
-		x += 4;
-		printf("-> type: %d\n", type);
-		if (l < x + 4) {
-			goto dump;
-		}
-		type = DVAL_LH(buff, x);
-		x += 4;
-		printf("   length: %d, ", type);
-		lskip = ((type + 3) & ~3) - type;
-		while (type--) {
-			if (l <= x) {
-				goto dump;
-			}
-			printf("%02X ", buff[x++]);
-		}
-		printf("\n");
-		if (lskip) {
-			printf("   skip: ");
-			while (lskip--) {
-				if (l <= x) {
-					goto dump;
-				}
-				printf("%02X ", buff[x++]);
-			}
-			printf("\n");
-		}
-	}
-	*pos = x;
-	return 0;
-dump:;
-	printf("end of buffer\n");
-	*pos = x;
-	return 1;
-}
-
 int main(int argc, char *argv[]) {
 	NWDSCCODE dserr;
 	NWDSContextHandle ctx;
 	NWCONN_HANDLE conn, conn2;
-	char* objectname = "[Root]";
-	char* context = "OrgUnit.Org.Country";
-	char* server = "CDROM";
+	const char* objectname = "[Root]";
+	const char* context = "OrgUnit.Org.Country";
+	const char* server = "CDROM";
 	int opt;
 	u_int32_t ctxflag = 0;
 	u_int32_t confidence = 0;
@@ -130,8 +79,8 @@ int main(int argc, char *argv[]) {
 	
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
