@@ -1,10 +1,10 @@
 #include <time.h>
 #include <stdio.h>
-#include <locale.h>
+#include "private/libintl.h"
 
 time_t clk;
 
-void dotimes(void) {
+static void dotimes(void) {
 	struct tm* tm;
 	char x[1000];
 	char src[1000];
