@@ -1,7 +1,7 @@
 /*
     nwmsg.c - Fetch NetWare broadcast messages and write to the user
     Copyright (C) 1996 by Volker Lendecke
-  
+    
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
@@ -22,6 +22,12 @@
 	0.00  1996			Volker Lendecke
 		Initial revision.
 
+	0.01  1999			Petr Vandrovec <vandrove@vc.cvut.cz>
+		Checking for 'mesg n' on all terminals.
+
+	1.00  1999, November 20		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Added license.
+  
  */
 
 #include <pwd.h>
@@ -29,7 +35,6 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <stdlib.h>
-#include <string.h>
 #include <stdio.h>
 #include <sys/ioctl.h>
 #include <sys/wait.h>
@@ -39,10 +44,14 @@
 #include <paths.h>
 #include <utmp.h>
 #include <mntent.h>
+#include <string.h>
 #include <errno.h>
 #include <ncp/nwcalls.h>
 
-static int search_utmp(char *user, char *tty);
+#include "private/libintl.h"
+#define _(X) gettext(X)
+
+static int search_utmp(const char *user, char *tty);
 
 static char *progname;
 
@@ -51,20 +60,17 @@ main(int argc, char *argv[])
 {
 	struct ncp_conn *conn;
 	char message[256];
-
 	char *mount_point;
 	uid_t uid;
 	struct passwd *pwd;
-	char tty[256];
 	char tty_path[256];
 	FILE *tty_file;
-	FILE *mtab;
-	struct mntent *mnt;
 	long err;
+	char sn[256];
 
-	char tknwmsg_command[256];
-	int error_level;
-
+	setlocale(LC_ALL, "");
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 
 	progname = argv[0];
 
@@ -72,96 +78,69 @@ main(int argc, char *argv[])
 
 	if (argc != 2)
 	{
-		fprintf(stderr, "usage: %s mount-point\n",
+		fprintf(stderr, _("usage: %s mount-point\n"),
 			progname);
 		exit(1);
 	}
 	mount_point = argv[1];
 	if ((err = ncp_open_mount(mount_point, &conn)) != 0)
 	{
-		com_err(progname, err, "in ncp_open_mount");
+		com_err(progname, err, _("in ncp_open_mount"));
 		exit(1);
 	}
 	if (ncp_get_broadcast_message(conn, message) != 0)
 	{
-		fprintf(stderr, "%s: could not get broadcast message\n",
+		fprintf(stderr, _("%s: could not get broadcast message\n"),
 			progname);
 		ncp_close(conn);
 		exit(1);
 	}
 	if (strlen(message) == 0)
 	{
-		syslog(LOG_DEBUG, "no message");
+		ncp_close(conn);
+		syslog(LOG_DEBUG, _("no message"));
 		exit(0);
 	}
 #if 0
-	syslog(LOG_DEBUG, "message: %s", message);
+	syslog(LOG_DEBUG, _("message: %s"), message);
 #endif
 
-	err = NWCCGetConnInfo(conn, NWCC_INFO_MOUNT_UID, sizeof(uid), &uid);
-	if (err)
-	{
-		fprintf(stderr, "%s: could not get uid on connection: %s\n",
-			progname, strnwerror(err));
+	if (NWCCGetConnInfo(conn, NWCC_INFO_MOUNT_UID, sizeof(uid), &uid)) {
+		fprintf(stderr, _("%s: could not get uid on connection: %s\n"),
+			progname, strerror(errno));
 		ncp_close(conn);
 		exit(1);
 	}
+	if (NWCCGetConnInfo(conn, NWCC_INFO_SERVER_NAME, sizeof(sn), sn)) {
+		strcpy(sn, _("<unknown>"));
+	}
 	ncp_close(conn);
 
 	if ((pwd = getpwuid(uid)) == NULL)
 	{
-		fprintf(stderr, "%s: user %d not known\n",
+		fprintf(stderr, _("%s: user %d not known\n"),
 			progname, uid);
 		exit(1);
 	}
-	if ((mtab = fopen(MOUNTED, "r")) == NULL)
-	{
-		fprintf(stderr, "%s: can't open %s\n",
-			progname, MOUNTED);
-		exit(1);
-	}
-	while ((mnt = getmntent(mtab)) != NULL)
-	{
-		if (strcmp(mnt->mnt_dir, mount_point) == 0)
-		{
-			break;
-		}
-	}
-
-	if (mnt == NULL)
-	{
-		syslog(LOG_DEBUG, "cannot find mtab entry\n");
-	}
-	if (search_utmp(pwd->pw_name, tty) != 0)
+	if (search_utmp(pwd->pw_name, tty_path) != 0)
 	{
 		exit(1);
 	}
-	sprintf(tty_path, "/dev/%s", tty);
 	if ((tty_file = fopen(tty_path, "w")) == NULL)
 	{
-		fprintf(stderr, "%s: cannot open %s: %s\n",
+		fprintf(stderr, _("%s: cannot open %s: %s\n"),
 			progname, tty_path, strerror(errno));
 		exit(1);
 	}
-	fprintf(tty_file, "\r\n\007\007\007Message from NetWare Server: %s\r\n",
-		mnt->mnt_fsname);
-	fprintf(tty_file, "%s\r\n", message);
-
-
-	//formulate the full system command for the X notice...
-	strcat(tknwmsg_command, "/usr/bin/tknwmsg -display :0 ");
-	strcat(tknwmsg_command, "Message from NetWare Server:  ");
-	strcat(tknwmsg_command, mnt->mnt_fsname);
-	strcat(tknwmsg_command, "  ");
-	strcat(tknwmsg_command, message);
-	strcat(tknwmsg_command, " &");
-
-	//execute this system command...
-	error_level = system(tknwmsg_command);
-
-
+	fprintf(tty_file, _("\r\n\007\007\007Message from NetWare Server: %s\r\n%s\r\n"),
+		sn, message);
 	fclose(tty_file);
-	fclose(mtab);
+	if (fork() == 0) {
+		char val[256 + 256 + 256];
+		
+		sprintf(val, _("Message from Netware Server: %s\n%s"), sn, message);
+		execl("/usr/bin/tknwmsg", "/usr/bin/tknwmsg", "-display", ":0", val, NULL);
+	}
 	return 0;
 }
 
@@ -172,17 +151,15 @@ main(int argc, char *argv[])
  *     and the access time
  */
 static int
-term_chk(char *tty, int *msgsokP, time_t * atimeP, int *showerror)
+term_chk(const char *path, int *msgsokP, time_t * atimeP, int *showerror)
 {
 	struct stat s;
-	char path[MAXPATHLEN];
 
-	(void) sprintf(path, "/dev/%s", tty);
 	if (stat(path, &s) < 0)
 	{
 		if (showerror)
 			(void) fprintf(stderr,
-				    "write: %s: %s\n", path, strerror(errno));
+				    _("write: %s: %s\n"), path, strerror(errno));
 		return (1);
 	}
 	*msgsokP = (s.st_mode & (S_IWRITE >> 3)) != 0;	/* group write bit */
@@ -202,38 +179,37 @@ term_chk(char *tty, int *msgsokP, time_t * atimeP, int *showerror)
  * writing from, unless that's the only terminal with messages enabled.
  */
 static int
-search_utmp(char *user, char *tty)
+search_utmp(const char *user, char *tty)
 {
 	struct utmp u;
 	time_t bestatime, atime;
-	int ufd, nloggedttys, nttys, msgsok, user_is_me;
+	int ufd, nloggedttys, nttys, msgsok;
 
-	char atty[sizeof(u.ut_line) + 1];
+	char atty[5 + sizeof(u.ut_line) + 1];
 
 	if ((ufd = open(_PATH_UTMP, O_RDONLY)) < 0)
 	{
-		perror("utmp");
+		perror(_("utmp"));
 		return -1;
 	}
 	nloggedttys = nttys = 0;
 	bestatime = 0;
-	user_is_me = 0;
+	memcpy(atty, "/dev/", 5);
 	while (read(ufd, (char *) &u, sizeof(u)) == sizeof(u))
 		if (strncmp(user, u.ut_name, sizeof(u.ut_name)) == 0)
 		{
 			++nloggedttys;
 
-			(void) strncpy(atty, u.ut_line, sizeof(u.ut_line));
-			atty[sizeof(u.ut_line)] = '\0';
+			strncpy(atty + 5, u.ut_line, sizeof(u.ut_line));
+			atty[5 + sizeof(u.ut_line)] = '\0';
 
+			if (u.ut_type != USER_PROCESS)
+				continue;	/* it's not a valid entry */
 			if (term_chk(atty, &msgsok, &atime, 0))
 				continue;	/* bad term? skip */
 			if (!msgsok)
 				continue;	/* skip ttys with msgs off */
 
-			if (u.ut_type != USER_PROCESS)
-				continue;	/* it's not a valid entry */
-
 			++nttys;
 			if (atime > bestatime)
 			{
@@ -244,7 +220,12 @@ search_utmp(char *user, char *tty)
 	(void) close(ufd);
 	if (nloggedttys == 0)
 	{
-		(void) fprintf(stderr, "write: %s is not logged in\n", user);
+		(void) fprintf(stderr, _("nwmsg: %s is not logged in\n"), user);
+		return -1;
+	}
+	if (!bestatime)
+	{
+		(void) fprintf(stderr, _("nwmsg: %s ignores messages\n"), user);
 		return -1;
 	}
 	return 0;
