@@ -22,6 +22,10 @@
 	0.00  1995			Volker Lendecke
 		Initial revision.
 
+	1.00  2001, September 15	Petr Vandrovec <vandrove@vc.cvut.cz>
+		Fixes for SWIG processing. Unwind nested structs so names
+		are defined here and not by SWIG.
+
  */
 
 #ifndef _IPXLIB_H
@@ -62,7 +66,11 @@ struct sap_server_ident
 	u_int16_t	server_type __attribute__((packed));
 	char		server_name[48] __attribute__((packed));
 	IPXNet		server_network __attribute__((packed));
+#ifdef SWIG
+	u_int8_t	server_node[6] __attribute__((packed));
+#else
 	IPXNode		server_node __attribute__((packed));
+#endif
 	IPXPort		server_port __attribute__((packed));
 	u_int16_t	intermediate_network __attribute__((packed));
 };
@@ -70,20 +78,25 @@ struct sap_server_ident
 #define IPX_RIP_REQUEST (0x1)
 #define IPX_RIP_RESPONSE (0x2)
 
-struct ipx_rip_packet
-{
-	u_int16_t operation __attribute__((packed));
-	struct ipx_rt_def
-	{
-		u_int32_t network __attribute__((packed));
-		u_int16_t hops __attribute__((packed));
-		u_int16_t ticks __attribute__((packed));
-	}
-	rt[1] __attribute__((packed));
+struct ipx_rt_def {
+	u_int32_t network __attribute__((packed));
+	u_int16_t hops __attribute__((packed));
+	u_int16_t ticks __attribute__((packed));
 };
 
+struct ipx_rip_packet
+{
+	u_int16_t		operation __attribute__((packed));
+	struct ipx_rt_def	rt[1] __attribute__((packed));
+};
+
+#ifdef SWIG
+#define IPX_BROADCAST_NODE "\xff\xff\xff\xff\xff\xff"
+#define IPX_THIS_NODE      "\0\0\0\0\0\0"
+#else
 #define IPX_BROADCAST_NODE ("\xff\xff\xff\xff\xff\xff")
 #define IPX_THIS_NODE      ("\0\0\0\0\0\0")
+#endif
 #define IPX_THIS_NET (0)
 
 #ifndef IPX_NODE_LEN
