@@ -33,6 +33,10 @@
 	1.00  1999, November 20		Petr Vandrovec <vandrove@vc.cvut.cz>
 		Added license.
   
+	1.01  2001, November 4		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Added NW_NS_LONG definition.
+		Added couple of SWIG fixes.
+
  */
 
 #ifndef _LINUX_NCP_H
@@ -73,6 +77,18 @@ struct ncp_reply_header {
 
 #define NCP_VOLNAME_LEN (16)
 #define NCP_NUMBER_OF_VOLUMES (64)
+#ifdef SWIG
+struct ncp_volume_info {
+	u_int32_t total_blocks;
+	u_int32_t free_blocks;
+	u_int32_t purgeable_blocks;
+	u_int32_t not_yet_purgeable_blocks;
+	u_int32_t total_dir_entries;
+	u_int32_t available_dir_entries;
+	u_int8_t sectors_per_block;
+	fixedCharArray volume_name[NCP_VOLNAME_LEN + 1];
+};
+#else
 struct ncp_volume_info {
 	u_int32_t total_blocks;
 	u_int32_t free_blocks;
@@ -83,28 +99,17 @@ struct ncp_volume_info {
 	u_int8_t sectors_per_block;
 	char volume_name[NCP_VOLNAME_LEN + 1];
 };
-
-/* these define the attribute byte as seen by NCP */
-/* FIXME: Create counterparts "as seen by host" i.e. aRONLY always 0x1 */
-#define aRONLY     (ntohl(0x01000000))
-#define aHIDDEN    (ntohl(0x02000000))
-#define aSYSTEM    (ntohl(0x04000000))
-#define aEXECUTE   (ntohl(0x08000000))
-#define aDIR       (ntohl(0x10000000))
-#define aARCH      (ntohl(0x20000000))
-
-#define AR_READ      (ntohs(0x0100))
-#define AR_WRITE     (ntohs(0x0200))
-#define AR_EXCLUSIVE (ntohs(0x2000))
+#endif
 
 #define NCP_FILE_ID_LEN 6
 
 /* Defines for Name Spaces */
-#define NW_NS_DOS     0
-#define NW_NS_MAC     1
-#define NW_NS_NFS     2
-#define NW_NS_FTAM    3
-#define NW_NS_OS2     4
+#define NW_NS_DOS	0
+#define NW_NS_MAC	1
+#define NW_NS_NFS	2
+#define NW_NS_FTAM	3
+#define NW_NS_OS2	4
+#define NW_NS_LONG	NW_NS_OS2
 
 #define	RIM_NAME		0x00000001
 #define	RIM_SPACE_ALLOCATED	0x00000002
@@ -132,16 +137,21 @@ struct ncp_volume_info {
 #define RIM_EFFECTIVE_RIGHTS	0x00400000
 #define RIM_MAC_TIMES		0x00800000
 #define RIM_LAST_ACCESS_TIME	0x01000000
+#ifdef MAKE_NCPLIB
+#define RIM_UNKNOWN25		0x02000000	/* fixme! */
+#endif
+#define RIM_SIZE64		0x04000000
 #define RIM_NSS_LARGE_SIZES	0x40000000
 #define RIM_COMPRESSED_INFO	0x80000000U
 
 /* open/create modes */
-#define OC_MODE_OPEN		0x01
-#define OC_MODE_TRUNCATE	0x02
-#define OC_MODE_REPLACE 	0x02
-#define OC_MODE_CREATE		0x08
-#define OC_MODE_READONLY_OK	0x40
-#define OC_MODE_CALLBACK	0x80
+#define OC_MODE_OPEN			0x01
+#define OC_MODE_TRUNCATE		0x02
+#define OC_MODE_REPLACE 		0x02
+#define OC_MODE_CREATE			0x08
+#define OC_MODE_OPEN_64BIT_ACCESS	0x20
+#define OC_MODE_READONLY_OK		0x40
+#define OC_MODE_CALLBACK		0x80
 
 /* open/create results */
 #define OC_ACTION_NONE		0x00
@@ -163,6 +173,38 @@ struct ncp_volume_info {
 #define AR_OPEN_COMPRESSED 0x0100
 #endif
 
+#ifdef SWIG
+struct nw_info_struct {
+	u_int32_t spaceAlloc __attribute__((packed));
+	u_int32_t attributes __attribute__((packed));
+	u_int16_t flags __attribute__((packed));
+	u_int32_t dataStreamSize __attribute__((packed));
+	u_int32_t totalStreamSize __attribute__((packed));
+	u_int16_t numberOfStreams __attribute__((packed));
+	u_int16_t creationTime __attribute__((packed));
+	u_int16_t creationDate __attribute__((packed));
+	u_int32_t creatorID __attribute__((packed));
+	u_int16_t modifyTime __attribute__((packed));
+	u_int16_t modifyDate __attribute__((packed));
+	u_int32_t modifierID __attribute__((packed));
+	u_int16_t lastAccessDate __attribute__((packed));
+	u_int16_t archiveTime __attribute__((packed));
+	u_int16_t archiveDate __attribute__((packed));
+	u_int32_t archiverID __attribute__((packed));
+	u_int16_t inheritedRightsMask __attribute__((packed));
+	u_int32_t dirEntNum __attribute__((packed));
+	u_int32_t DosDirNum __attribute__((packed));
+	u_int32_t volNumber __attribute__((packed));
+	u_int32_t EADataSize __attribute__((packed));
+	u_int32_t EAKeyCount __attribute__((packed));
+	u_int32_t EAKeySize __attribute__((packed));
+	u_int32_t NSCreator __attribute__((packed));
+%pragma(swig) readonly
+	u_int8_t nameLen __attribute__((packed));
+%pragma(swig) readwrite
+	byteLenPrefixCharArray entryName[255] __attribute__((packed));
+};
+#else
 struct nw_info_struct {
 	u_int32_t spaceAlloc __attribute__((packed));
 	u_int32_t attributes __attribute__((packed));
@@ -191,6 +233,7 @@ struct nw_info_struct {
 	u_int8_t nameLen __attribute__((packed));
 	u_int8_t entryName[256] __attribute__((packed));
 };
+#endif
 
 /* modify mask - use with MODIFY_DOS_INFO structure */
 #define DM_ATTRIBUTES		  (0x00000002L)
@@ -224,6 +267,16 @@ struct nw_modify_dos_info {
 	u_int32_t maximumSpace __attribute__((packed));
 };
 
+#ifdef SWIG
+struct nw_file_info {
+	struct nw_info_struct i;
+	int opened;
+	int access;
+	u_int32_t server_file_handle __attribute__((packed));
+	u_int8_t open_create_action __attribute__((packed));
+	fixedArray file_handle[6] __attribute__((packed));
+};
+#else
 struct nw_file_info {
 	struct nw_info_struct i;
 	int opened;
@@ -232,6 +285,7 @@ struct nw_file_info {
 	u_int8_t open_create_action __attribute__((packed));
 	u_int8_t file_handle[6] __attribute__((packed));
 };
+#endif
 
 struct nw_search_sequence {
 	u_int8_t volNumber __attribute__((packed));
