@@ -25,6 +25,9 @@
 	0.01  1996			J.F. Chadima
 		Modified for sparc.
 
+	1.00  2001, March 4		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Added NCP_BINDERY_TREE.
+
  */
 
 #ifndef _NCP_H
@@ -53,6 +56,7 @@ typedef u_int32_t NWObjectID;
 #define NCP_BINDERY_ADMIN       (0x000b)
 #define NCP_BINDERY_BSERVER     (0x0026)        /* Bridge Server */
 #define NCP_BINDERY_ADVPSERVER  (0x0047)        /* Advertising Print Server */
+#define NCP_BINDERY_TREE	(0x0278)	/* NDS Tree */
 #define NCP_BINDERY_NTSERVER    (0x0640)        /* NT Server */
 
 #define NCP_BINDERY_ID_WILDCARD (0xffffffff)
@@ -66,21 +70,33 @@ typedef u_int32_t NWObjectID;
 struct ncp_bindery_object {
 	NWObjectID object_id;
 	NWObjectType object_type;
+#ifdef SWIG
+	fixedCharArray object_name[NCP_BINDERY_NAME_LEN];
+#else
 	u_int8_t object_name[NCP_BINDERY_NAME_LEN];
+#endif
 	u_int8_t object_flags;
 	u_int8_t object_security;
 	u_int8_t object_has_prop;
 };
 
 struct nw_property {
+#ifdef SWIG
+	fixedArray value[128];
+#else
 	u_int8_t value[128];
+#endif
 	u_int8_t more_flag;
 	u_int8_t property_flag;
 };
 
 struct prop_net_address {
 	u_int32_t network __attribute__((packed));
+#ifdef SWIG
+	fixedArray node[IPX_NODE_LEN];
+#else
 	u_int8_t node[IPX_NODE_LEN] __attribute__((packed));
+#endif
 	u_int16_t port __attribute__((packed));
 };
 
@@ -93,8 +109,13 @@ struct ncp_filesearch_info {
 
 #define NCP_MAX_FILENAME (14)
 struct ncp_file_info {
+#ifdef SWIG
+	fixedArray file_id[NCP_FILE_ID_LEN];
+	fixedCharArray file_name[NCP_MAX_FILENAME + 1];
+#else	
 	u_int8_t file_id[NCP_FILE_ID_LEN];
 	char file_name[NCP_MAX_FILENAME + 1];
+#endif
 	u_int8_t file_attributes;
 	u_int8_t file_mode;
 	u_int32_t file_length;
@@ -104,6 +125,36 @@ struct ncp_file_info {
 	u_int16_t update_time;
 };
 
+#ifdef SWIG
+struct nw_queue_job_entry {
+	u_int16_t InUse __attribute__((packed));
+	u_int32_t prev __attribute__((packed));
+	u_int32_t next __attribute__((packed));
+	u_int32_t ClientStation __attribute__((packed));
+	u_int32_t ClientTask __attribute__((packed));
+	u_int32_t ClientObjectID __attribute__((packed));
+	u_int32_t TargetServerID __attribute__((packed));
+	fixedArray TargetExecTime[6] __attribute__((packed));
+	fixedArray JobEntryTime[6] __attribute__((packed));
+	u_int32_t JobNumber __attribute__((packed));
+	u_int16_t JobType __attribute__((packed));
+	u_int16_t JobPosition __attribute__((packed));
+	u_int16_t JobControlFlags __attribute__((packed));
+	u_int8_t FileNameLen __attribute__((packed));
+	byteLenPrefixCharArray JobFileName[13] __attribute__((packed));
+	u_int32_t JobFileHandle __attribute__((packed));
+	u_int32_t ServerStation __attribute__((packed));
+	u_int32_t ServerTaskNumber __attribute__((packed));
+	u_int32_t ServerObjectID __attribute__((packed));
+	fixedCharArray JobTextDescription[50] __attribute__((packed));
+	fixedArray ClientRecordArea[152] __attribute__((packed));
+};
+
+struct queue_job {
+	struct nw_queue_job_entry j;
+	fixedArray file_handle[6];
+};
+#else
 struct nw_queue_job_entry {
 	u_int16_t InUse __attribute__((packed));
 	u_int32_t prev __attribute__((packed));
@@ -132,6 +183,7 @@ struct queue_job {
 	struct nw_queue_job_entry j;
 	u_int8_t file_handle[6];
 };
+#endif
 
 #define QJE_OPER_HOLD	0x80
 #define QJE_USER_HOLD	0x40
@@ -148,6 +200,22 @@ struct queue_job {
 #define   EXPAND_TABS    0x4000
 #define   PRINT_BANNER   0x8000
 
+#ifdef SWIG
+struct print_job_record {
+	u_int8_t Version __attribute__((packed));
+	u_int8_t TabSize __attribute__((packed));
+	u_int16_t Copies __attribute__((packed));
+	u_int16_t CtrlFlags __attribute__((packed));
+	u_int16_t Lines __attribute__((packed));
+	u_int16_t Rows __attribute__((packed));
+	fixedCharArray FormName[16] __attribute__((packed));
+	fixedArray Reserved[6] __attribute__((packed));
+	fixedCharArray BannerName[13] __attribute__((packed));
+	fixedCharArray FnameBanner[13] __attribute__((packed));
+	fixedCharArray FnameHeader[14] __attribute__((packed));
+	fixedCharArray Path[80] __attribute__((packed));
+};
+#else
 struct print_job_record {
 	u_int8_t Version __attribute__((packed));
 	u_int8_t TabSize __attribute__((packed));
@@ -162,5 +230,6 @@ struct print_job_record {
 	char FnameHeader[14] __attribute__((packed));
 	char Path[80] __attribute__((packed));
 };
+#endif
 
 #endif				/* _NCP_H */
