@@ -105,38 +105,6 @@ typedef u_int64_t ncp_off64_t;
 extern "C" {
 #endif
 
-static inline word
-WVAL_HL(const void * buf, int pos)
-{
-	return PVAL(buf, pos) << 8 | PVAL(buf, pos + 1);
-}
-
-static inline dword
-DVAL_HL(const void * buf, int pos)
-{
-	return WVAL_HL(buf, pos) << 16 | WVAL_HL(buf, pos + 2);
-}
-
-static inline void
-WSET_HL(void * buf, int pos, word val)
-{
-	BSET(buf, pos, val >> 8);
-	BSET(buf, pos + 1, val & 0xff);
-}
-
-static inline void
-DSET_HL(void * buf, int pos, dword val)
-{
-	WSET_HL(buf, pos, val >> 16);
-	WSET_HL(buf, pos + 2, val & 0xffff);
-}
-
-static inline void
-QSET_HL(void * buf, int pos, u_int64_t val) {
-	DSET_HL(buf, pos, val >> 32);
-	DSET_HL(buf, pos + 4, val);
-}
-
 /* we know that the 386 can handle misalignment and has the "right" 
    byteorder */
 #if defined(__i386__)
@@ -177,6 +145,36 @@ QSET_LH(void * buf, int pos, u_int64_t val)
 	*((u_int64_t *) (((u_int8_t*)buf) + pos)) = val;
 }
 
+static inline word
+WVAL_HL(const void * buf, int pos)
+{
+	return ntohs(WVAL_LH(buf, pos));
+}
+
+static inline dword
+DVAL_HL(const void * buf, int pos)
+{
+	return ntohl(DVAL_LH(buf, pos));
+}
+
+static inline void
+WSET_HL(void * buf, int pos, word val)
+{
+	WSET_LH(buf, pos, htons(val));
+}
+
+static inline void
+DSET_HL(void * buf, int pos, dword val)
+{
+	DSET_LH(buf, pos, htonl(val));
+}
+
+static inline __attribute__((always_inline)) void
+QSET_HL(void * buf, int pos, u_int64_t val) {
+	DSET_HL(buf, pos, val >> 32);
+	DSET_HL(buf, pos + 4, val);
+}
+
 #else
 
 static inline word
@@ -218,6 +216,38 @@ QSET_LH(void * buf, int pos, u_int64_t val)
 	DSET_LH(buf, pos + 4, val >> 32);
 }
 
+static inline word
+WVAL_HL(const void * buf, int pos)
+{
+	return PVAL(buf, pos) << 8 | PVAL(buf, pos + 1);
+}
+
+static inline dword
+DVAL_HL(const void * buf, int pos)
+{
+	return WVAL_HL(buf, pos) << 16 | WVAL_HL(buf, pos + 2);
+}
+
+static inline void
+WSET_HL(void * buf, int pos, word val)
+{
+	BSET(buf, pos, val >> 8);
+	BSET(buf, pos + 1, val & 0xff);
+}
+
+static inline void
+DSET_HL(void * buf, int pos, dword val)
+{
+	WSET_HL(buf, pos, val >> 16);
+	WSET_HL(buf, pos + 2, val & 0xffff);
+}
+
+static inline void
+QSET_HL(void * buf, int pos, u_int64_t val) {
+	DSET_HL(buf, pos, val >> 32);
+	DSET_HL(buf, pos + 4, val);
+}
+
 #endif
 
 static inline u_int64_t
