@@ -490,6 +490,12 @@ NWCCODE NWScanNCPExtensions(NWCONN_HANDLE __conn, nuint32* __iter,
 		char* __extname, nuint8* __majorVersion, 
 		nuint8* __minorVersion, nuint8* __revision,
 		nuint8 __queryData[32]);
+NWCCODE NWFragNCPExtensionRequest(NWCONN_HANDLE conn, nuint32 NCPExtensionID, 
+		nuint reqFragCount, NW_FRAGMENT* reqFragList, 
+		nuint replyFragCount, NW_FRAGMENT* replyFragList);
+NWCCODE NWNCPExtensionRequest(NWCONN_HANDLE conn, nuint32 NCPExtensionID,
+                const void* requestData, size_t requestDataLen,
+		void* replyData, size_t* replyDataLen);
 
 NWCCODE NWEnableBroadcasts(NWCONN_HANDLE __conn);
 NWCCODE NWDisableBroadcasts(NWCONN_HANDLE __conn);
