@@ -1,9 +1,4 @@
-#include <stdio.h>
-#include <sys/types.h>
-#include <kernel/ipx.h>
-#include <netinet/in.h>
-#include <sys/socket.h>
-#include <errno.h>
+#include "samples.h"
 
 int
 main(int argc, char **argv)
