@@ -25,9 +25,10 @@
 	1.00  1999, November 20		Petr Vandrovec <vandrove@vc.cvut.cz>
 		Added license.
 
- */
-#include "config.h"
+	1.01  2001, June 16		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Cleanup some compilation warnings.
 
+ */
 #include <stdio.h>
 #include <ctype.h>
 #include <errno.h>
@@ -46,7 +47,7 @@
 #include <ncp/kernel/types.h>
 #include "netlink.h"
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 #define NOVELL_SCMD_PORT	(2645)
@@ -153,8 +154,8 @@ int main(int argc, char* argv[]) {
 	int fd_ipx;
 	
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	{
 		char* i;
@@ -170,8 +171,6 @@ int main(int argc, char* argv[]) {
 				break;
 			case 'l':
 				{
-					struct hostent* hent;
-
 					hent = gethostbyname(optarg);
 					if (!hent) {
 						fprintf(stderr, _("%s: %s: "),
