@@ -20,10 +20,12 @@
 
 struct option options[] =
 {
-	{"auto_primary", required_argument, NULL, 1},
-	{"auto_interface", required_argument, NULL, 2},
-	{"help", no_argument, NULL, 3},
-	{NULL, 0, NULL, 0}
+	{ "auto_primary",	required_argument,	NULL, 'p'},
+	{ "auto-primary",	required_argument,	NULL, 'p'},
+	{ "auto_interface",	required_argument,	NULL, 'i'},
+	{ "auto-interface",	required_argument,	NULL, 'i'},
+	{ "help",		no_argument,		NULL, 'h'},
+	{ NULL,			0,			NULL, 0}
 };
 
 static char *progname;
@@ -45,13 +47,15 @@ map_string_to_bool(char *opt)
 	if ((strcasecmp(opt, "ON") == 0) ||
 	    (strcasecmp(opt, "TRUE") == 0) ||
 	    (strcasecmp(opt, "SET") == 0) ||
-	    (strcasecmp(opt, "YES") == 0))
+	    (strcasecmp(opt, "YES") == 0) ||
+	    (strcasecmp(opt, "1") == 0))
 	{
 		return 1;
 	} else if ((strcasecmp(opt, "OFF") == 0) ||
 		   (strcasecmp(opt, "FALSE") == 0) ||
 		   (strcasecmp(opt, "CLEAR") == 0) ||
-		   (strcasecmp(opt, "NO") == 0))
+		   (strcasecmp(opt, "NO") == 0) ||
+		   (strcasecmp(opt, "0") == 0))
 	{
 		return 0;
 	}
@@ -63,8 +67,7 @@ main(int argc, char **argv)
 {
 	int s;
 	int result;
-	char val;
-	int option_index = 0;
+	int val;
 	int got_auto_pri = 0;
 	int got_auto_itf = 0;
 	ipx_config_data data;
@@ -87,12 +90,12 @@ main(int argc, char **argv)
 		}
 		exit(-1);
 	}
-	while ((result = getopt_long(argc, argv, "", options,
-				     &option_index)) != -1)
+	while ((result = getopt_long(argc, argv, "hi:p:", options,
+				     NULL)) != -1)
 	{
 		switch (result)
 		{
-		case 1:
+		case 'p':
 			if (got_auto_pri)
 				break;
 			got_auto_pri++;
@@ -103,7 +106,11 @@ main(int argc, char **argv)
 				usage();
 				exit(-1);
 			}
-			result = ioctl(s, SIOCAIPXPRISLT, &val);
+			{
+				unsigned char v = val;
+
+				result = ioctl(s, SIOCAIPXPRISLT, &v);
+			}
 			if (result < 0)
 			{
 				fprintf(stderr, _("%s: ioctl: %s\n"), progname,
@@ -111,7 +118,7 @@ main(int argc, char **argv)
 				exit(-1);
 			}
 			break;
-		case 2:
+		case 'i':
 			if (got_auto_itf)
 				break;
 			got_auto_itf++;
@@ -122,7 +129,11 @@ main(int argc, char **argv)
 				usage();
 				exit(-1);
 			}
-			result = ioctl(s, SIOCAIPXITFCRT, &val);
+			{
+				unsigned char v = val;
+
+				result = ioctl(s, SIOCAIPXITFCRT, &v);
+			}
 			if (result < 0)
 			{
 				fprintf(stderr, _("%s: ioctl: %s\n"), progname,
@@ -130,7 +141,7 @@ main(int argc, char **argv)
 				exit(-1);
 			}
 			break;
-		case 3:
+		case 'h':
 			usage();
 			break;
 		}
