@@ -216,7 +216,7 @@ ipx_add_interface(int argc, char **argv)
 }
 
 static int
-ipx_delall_interface(int argc, char **argv)
+ipx_delall_interface(int argc __attribute__((unused)), char **argv __attribute__((unused)))
 {
 	struct sockaddr_ipx *sipx = (struct sockaddr_ipx *) &id.ifr_addr;
 	int s;
