@@ -120,7 +120,7 @@ ipx_add_internal_net(int argc, char **argv)
 }
 
 static int
-ipx_del_internal_net(int argc, char **argv)
+ipx_del_internal_net(int argc, char **argv __attribute__((unused)))
 {
 	struct sockaddr_ipx *sipx = (struct sockaddr_ipx *) &id.ifr_addr;
 	int s;
