@@ -1,20 +1,31 @@
-/* ipxparse.c */
+/*
+    ipxparse.c
+    Copyright 1996 Volker Lendecke, Goettingen, Germany
+    Copyright 1997, 1998, 1999, 2001 Petr Vandrovec, Prague, Czech Republic
 
-/* Copyright 1996 Volker Lendecke, Goettingen, Germany
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+
+    Revision history:
+
+	0.00  1996-1999			Volker Nendecke, Petr Vandrovec
+		Initial revision, different changes.
+		
+	1.00  2001, July 15		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Added #include <stdlib> to disable some warnings.
 
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
 #include <unistd.h>
@@ -31,6 +42,7 @@
 #include <sys/ioctl.h>
 #include <ncp/kernel/if.h>
 #include <signal.h>
+#include <stdlib.h>
 /* TBD */
 #include <netinet/ip.h>
 /* TBD */
