@@ -34,6 +34,7 @@
 
 #include <ncp/nwcalls.h>
 #include "nwnet_i.h"
+#include <string.h>
 
 #define CLASSDEF_ASN	0x0001
 #define CLASSDEF_TIMES	0x0002
@@ -274,6 +275,8 @@ NWDSCCODE NWDSPutClassItem(
 			if (!buf->attrCountPtr)
 				return ERR_BAD_VERB;
 			break;
+		/* DSV_READ_ATTR_DEF should not be there... NWDSPutAttrName 
+		   should be used with NWDSReadAttrDef */
 		case DSV_READ_ATTR_DEF:
 		case DSV_READ_CLASS_DEF:
 		case DSV_MODIFY_CLASS_DEF:
