@@ -50,8 +50,6 @@
 
 */
 
-#include "config.h"
-
 #include <ncp/nwcalls.h>
 #include "nwnet_i.h"
 
@@ -321,7 +319,7 @@ NWDSCCODE NWDSListPartitions(
 }
 
 NWDSCCODE NWDSGetPartitionExtInfoPtr(
-		NWDSContextHandle	ctx,
+	UNUSED( NWDSContextHandle	ctx),
 		Buf_T*			partitions,
 		char**			infoPtr,
 		char**			infoPtrEnd
