@@ -1321,7 +1321,7 @@ int upton_modmult (unitptr prod, unitptr multiplicand, unitptr multiplier)
 	after the program exits.
 	upton_burn() is aliased to modmult_burn().
 */
-void upton_burn(void)
+static void upton_burn(void)
 {
 	unitfill0(modulus,MAX_UNIT_PRECISION);
 	unitfill0(reciprocal,MAX_UNIT_PRECISION);
@@ -1713,9 +1713,9 @@ void smith_burn(void)
 #endif	/* SMITH */
 
 
-int countbits(const unit* r)
+unsigned int countbits(const unit* r)
 	/* Returns number of significant bits in r */
-{	int bits;
+{	unsigned int bits;
 	short prec;
 	register unit bitmask;
 	init_bitsniffer(r,bitmask,prec,bits);
@@ -1723,13 +1723,14 @@ int countbits(const unit* r)
 } /* countbits */
 
 
+const char *copyright_notice(void);
 const char *copyright_notice(void)
 /* force linker to include copyright notice in the executable object image. */
 { return ("(c)1986 Philip Zimmermann"); } /* copyright_notice */
 
 
 int mp_modexp(register unitptr expout,register unitptr expin,
-	register unitptr exponent,const unit* modulus)
+	register unitptr exponent,const unit* pmodulus)
 {	/*	Russian peasant combined exponentiation/modulo algorithm.
 		Calls modmult instead of mult.
 		Computes:  expout = (expin**exponent) mod modulus
@@ -1751,27 +1752,27 @@ int mp_modexp(register unitptr expout,register unitptr expin,
 			return(-1); /* 0 to the 0th power means return error */
 		return(0);	/* otherwise, zero exponent means expout is 1 */
 	}
-	if (testeq(modulus,0))
+	if (testeq(pmodulus,0))
 		return(-2);		/* zero modulus means error */
 #if SLOP_BITS > 0	/* if there's room for sign bits */
-	if (mp_tstminus(modulus))
+	if (mp_tstminus(pmodulus))
 		return(-2);		/* negative modulus means error */
 #endif	/* SLOP_BITS > 0 */
-	if (mp_compare(expin,modulus) >= 0)
+	if (mp_compare(expin,pmodulus) >= 0)
 		return(-3); /* if expin >= modulus, return error */
-	if (mp_compare(exponent,modulus) >= 0)
+	if (mp_compare(exponent,pmodulus) >= 0)
 		return(-4); /* if exponent >= modulus, return error */
 
 	oldprecision = global_precision;	/* save global_precision */
 	/* set smallest optimum precision for this modulus */
-	set_precision(bits2units(countbits(modulus)+SLOP_BITS));
+	set_precision(bits2units(countbits(pmodulus)+SLOP_BITS));
 	/* rescale all these registers to global_precision we just defined */
-	rescale(modulus,oldprecision,global_precision);
+	rescale(pmodulus,oldprecision,global_precision);
 	rescale(expin,oldprecision,global_precision);
 	rescale(exponent,oldprecision,global_precision);
 	rescale(expout,oldprecision,global_precision);
 
-	if (stage_modulus(modulus))
+	if (stage_modulus(pmodulus))
 	{	set_precision(oldprecision);	/* restore original precision */
 		return(-5);		/* unstageable modulus (STEWART algorithm) */
 	}
@@ -1808,7 +1809,7 @@ int mp_modexp(register unitptr expout,register unitptr expin,
 #ifdef COUNTMULTS	/* diagnostic analysis */
 	{	long atomic_mults;
 		unsigned int unitcount,totalmults;
-		unitcount = bits2units(countbits(modulus));
+		unitcount = bits2units(countbits(pmodulus));
 		/* calculation assumes modsquare takes as long as a modmult: */
 		atomic_mults = (long) tally_modmults * (unitcount * unitcount);
 		atomic_mults += (long) tally_modsquares * (unitcount * unitcount);
@@ -1816,7 +1817,7 @@ int mp_modexp(register unitptr expout,register unitptr expin,
 		printf("%d+%d = %d modsqr+modmlt, at %d bits, %d words.\n",
 			tally_modsquares,tally_modmults,
 			tally_modsquares+tally_modmults,
-			countbits(modulus), unitcount);
+			countbits(pmodulus), unitcount);
 	}
 #endif	/* COUNTMULTS */
 
