@@ -51,6 +51,8 @@
 /*#define DEBUG_PRINT*/
 /*#define FIND_ISR */ /* if defined: show reasons for -330 invalid response */
 
+#define NCP_OBSOLETE
+
 #include "config.h"
 
 #include <string.h>
@@ -90,10 +92,6 @@ typedef unsigned char boolean;
 #define ISRPrint(X...) do {} while (0)
 #endif
 
-static void strcpy_cw(wchar_t *w, const char* s) {
-	while ((*w++ = *(const nuint8*)s++) != 0);
-}
-
 NWDSCCODE NWIsDSServer(NWCONN_HANDLE conn, char* treename) {
 	char buf[128];
 	size_t size;
@@ -255,7 +253,7 @@ static char keyprefix[] = {1, 0, 0, 0, 3, 0, 1, 0};
 static int initkey(const char *key, char **keyptr, size_t *keylen) { /* 1=ok, 0=err */
     if (!memcmp(key, keyprefix, 8)) {
         if (keylen) *keylen = WVAL_LH(key, 8);
-        if (keyptr) (const char *)(*keyptr) = key + 10;
+        if (keyptr) *keyptr = (char*)key + 10;
         return 1;
     } else
         return 0;
@@ -277,7 +275,7 @@ static int findchunk(const char *keyptr, int keylen, const char *chunk,
             if ((p[0] != chunk[0]) || (p[1] != chunk[1]))
                 p += 4 + (unsigned char)p[2] + (unsigned char)p[3];
             else {
-                if (chunkptr) (const char *)(*chunkptr) = p + 4;
+                if (chunkptr) *chunkptr = (char*)p + 4;
                 return (unsigned char)p[2] + (unsigned char)p[3];
             }
         }
@@ -1210,8 +1208,8 @@ static NWDSCCODE gen_auth_data(
 			mp_add(up, n_mod);
 		}
 		mp_modexp(up2, up, n_exp, n_mod);
-		((char *)up) += nblocksize; 
-		((char *)up2) += nblocksize_nw;
+		up = (unitptr)((char*)up + nblocksize);
+		up2 = (unitptr)((char*)up2 + nblocksize_nw);
 	}
 	nwhash2block(hashbuf, p+12, nblocksize_nw * 3);
 	nwhash2end(hashbuf);
@@ -1222,8 +1220,8 @@ static NWDSCCODE gen_auth_data(
 		mp_modexp(up2, n_key, n_temp, n_mod);
 		stage_modulus(n_mod);
 		mp_modmult(up2, up2, up); 
-		((char *)up) += nblocksize; 
-		((char *)up2) += nblocksize_nw;
+		up = (unitptr)((char*)up + nblocksize);
+		up2 = (unitptr)((char*)up2 + nblocksize_nw);
 	}
 	if (n_temp) {
     		mp_init0(n_temp);
