@@ -219,8 +219,9 @@ NWCCODE NWRequestSimple(NWCONN_HANDLE conn, nuint function,
 #ifndef MSG_DONTWAIT
 #define MSG_DONTWAIT 0
 #endif
-static int timedRecv(int fd, void* buff, size_t len, int timeout) {
+static int timedRecv(int fd, void* b, size_t len, int timeout) {
 	struct timeval tv;
+	unsigned char* buff = b;
 
 	tv.tv_sec = timeout / 1000000;
 	tv.tv_usec = timeout % 1000000;
@@ -245,7 +246,7 @@ static int timedRecv(int fd, void* buff, size_t len, int timeout) {
 
 			if (rd2 > len)
 				break;
-			(unsigned char*)buff += rd2;
+			buff += rd2;
 			len -= rd2;
 			if (!len)
 				return 0;
@@ -293,7 +294,7 @@ static int timedRecvMsg(int fd, struct iovec* v, size_t vnum, int timeout) {
 					return 0;
 				}
 			}
-			(char*)v->iov_base += rd2;
+			v->iov_base = (unsigned char*)v->iov_base + rd2;
 			v->iov_len -= rd2;
 		}
 	} while (1);
