@@ -96,7 +96,8 @@
 
 #if 1
 /*read hard degugging*/
- void printConn (NWCONN_HANDLE conn, int stage) {
+void printConn (NWCONN_HANDLE conn, int stage);
+void printConn (NWCONN_HANDLE conn, int stage) {
         printf("%s\n",conn->mount_point);
         printf ("------ info from kernel--------------------------------\n");
         printf ("infoV2.version %d\n",conn->i.version);
@@ -135,13 +136,11 @@
         printf ("serverInfo.version.revision %x\n",conn->serverInfo.version.revision);
 
         printf ("NET_ADDRESS_TYPE nt %x\n",conn->nt);
-
-
- }
+}
 #endif
 
 static int NWCIsPermanentConnection (NWCONN_HANDLE conn) {
-  return (ncp_get_conn_type(conn) == NCP_CONN_PERMANENT);
+	return (ncp_get_conn_type(conn) == NCP_CONN_PERMANENT);
 }
 
 NWCCODE NWCXGetPermConnInfo(NWCONN_HANDLE conn, nuint info, size_t len, void* buffer) {
@@ -354,81 +353,62 @@ NWCCODE NWCXGetPermConnListByServerName (NWCONN_HANDLE* conns , int maxEntries,
 }
 
 #ifdef NDS_SUPPORT
-/* copied from ndslib.c */
-static void strcpy_cw(wchar_t *w, const char* s) {
-        while ((*w++ = *(const nuint8*)s++) != 0);
-}
-
-NWDSCCODE NWDSCreateContextHandleMnt(NWDSContextHandle* ctx, const NWDSChar * treeName){
-
+NWDSCCODE NWDSSetContextHandleTree(NWDSContextHandle ctx, const NWDSChar * treeName)
+{
 #define MAXCONNS 64
-  NWDSCCODE err;
-  NWCONN_HANDLE conns[MAXCONNS];
+	NWDSCCODE err;
+	NWCONN_HANDLE conns[MAXCONNS];
+	int curEntries;
+	int i;
+	wchar_t treeNameW[MAX_DN_CHARS+1];
+	char treeNameUTF[MAX_DN_CHARS*4 + 1];
 
-  int curEntries=0;
-  NWDS_HANDLE dxh;
-  int i;
-  union __NWDSAuthInfo * ndai;
-  size_t authinfo_len;
-  wchar_t wc_treeName[MAX_DN_CHARS+1];
-
-  if (!treeName)
-      return ERR_NULL_POINTER;
-
-  strcpy_cw (wc_treeName,treeName);
-
-  err=NWDSCreateContextHandle (ctx);
-  if (err)
-       return err;
-
-  err= NWCXGetPermConnListByTreeName (conns,MAXCONNS,&curEntries,getuid(),treeName);
-  if (err) {
-     NWDSFreeContext(*ctx);
-     return (err);
-  }
-/*  printf ("got %d connexion(s) to %s \n",curEntries,treeName);*/
-  dxh=(*ctx)->ds_connection;
-  if (! dxh){  /* should not be ???*/
-           NWDSFreeContext(*ctx);
-           return EINVAL;
-   }
-  for (i=0; i <curEntries;i++) {
-     NWCONN_HANDLE conn = conns[i];
-     err=NWDSAddConnection (*ctx,conn);
-
-     if (err) {
-/*            printf ("error adding connection \n");*/
-            NWCCCloseConn(conn);
-            continue;
-     }
-     if (!dxh->authinfo) {
-/*        printf ("trying to get authinfo \n");*/
-        err = ncp_get_private_key(conn, NULL, &authinfo_len);
-        if (err)
-                  continue;       /* kernel without private key support */
-        if (!authinfo_len)
-                   continue;       /* no private key on this connection */
-        ndai = (union __NWDSAuthInfo*)malloc(authinfo_len);
-        if (!ndai)
-                continue;       /* not enough memory */
-        err = ncp_get_private_key(conn, ndai, &authinfo_len);
-        if (err) {
-                free(ndai);
-                continue;
-        }
-/*        printf ("got authinfo \n");*/
-        mlock(ndai, authinfo_len);
-        dxh->authinfo = ndai;
-        if (dxh->dck.tree_name)
-            free(dxh->dck.tree_name);
-        dxh->dck.tree_name=wcsdup(wc_treeName);
-     }
-
-  }
-  return 0;
+	if (!treeName)
+		return ERR_NULL_POINTER;
 
+	err = NWDSXlateFromCtx(ctx, treeNameW, sizeof(treeNameW), treeName);
+	if (err)
+		return err;
+	err = iconv_wchar_t_to_external(treeNameW, treeNameUTF, sizeof(treeNameUTF));
+	if (err)
+		return err;
+	err = NWDSSetTreeNameW(ctx, treeNameW);
+	if (err) {
+		return err;
+	}
+	err = NWCXGetPermConnListByTreeName(conns, MAXCONNS, &curEntries, getuid(), treeNameUTF);
+	if (err) {
+		return err;
+	}
+	for (i = 0; i < curEntries; i++) {
+		NWCONN_HANDLE conn = conns[i];
+		err = NWDSAddConnection(ctx, conn);
+		if (err) {
+			NWCCCloseConn(conn);
+			continue;
+		}
+	}
+	return 0;
 }
 
+NWDSCCODE NWDSCreateContextHandleMnt(NWDSContextHandle* pctx, const NWDSChar * treeName)
+{
+	NWDSCCODE err;
+	NWDSContextHandle ctx;
+
+	if (!pctx) {
+		return ERR_NULL_POINTER;
+	}
+	err = NWDSCreateContextHandle(&ctx);
+	if (err)
+		return err;
+	err = NWDSSetContextHandleTree(ctx, treeName);
+	if (err)
+		NWDSFreeContext(ctx);
+	else
+		*pctx = ctx;
+	return err;
+}
 
 //#define NOENV 1  <-- testing reading of .nwinfos file
 #undef NOENV
@@ -497,6 +477,10 @@ static char* readnwinfosfile (char * user, const char * info, const char * forTr
                 *err = errno;
                 return NULL;
         }
+        if (st.st_uid != getuid()) {
+                *err = EACCES;
+                return NULL;
+        }
         if ((st.st_mode & (S_IRWXO | S_IRWXG)) != 0) {
                 *err = NCPLIB_INVALID_MODE;
                 return NULL;
@@ -833,98 +817,75 @@ NWDSCCODE NWCXSplitNameAndContext (NWDSContextHandle ctx, const NWDSChar * dn,
          and return them as strings with comma separators
 attributes with fields are emitted on a single line with "," as separator*/
 
-static NWDSCCODE __docopy_string (NWDSContextHandle ctx, const void* val,
+static NWDSCCODE __docopy_string (UNUSED(NWDSContextHandle ctx), const void* val,
                                    const enum SYNTAX synt, size_t currentSize,
                                    char* result, size_t maxSize){
-  NWDSCCODE err;
-  char tmpBuf [MAX_DN_BYTES+1];
-
+  int l;
 #ifdef DEBUG_PRINT
   printf ("__docopy_string got :%s synt = %d cursize=%d maxsize= %d\n",(char *)val,synt,currentSize,maxSize );
 #endif
 
-  if (currentSize >maxSize) return NWE_BUFFER_OVERFLOW;
+  if (currentSize > maxSize) return NWE_BUFFER_OVERFLOW;
   if (!result) return ERR_NULL_POINTER;
   switch (synt) {
 	case SYN_DIST_NAME:
-              /*
-	      err = NWDSAbbreviateName(ctx, val, tmpBuf);
-              if (err)
-                  return err;
-              //strcpy (result,tmpBuf);
-	      *************************/
-	     strcpy(result,val);
-              break;
 	case SYN_CI_STRING:
 	case SYN_CE_STRING:
         case SYN_PR_STRING:
 	case SYN_NU_STRING:
 	case SYN_TEL_NUMBER:
 	case SYN_CLASS_NAME:
-		strcpy(result,val);
-	        break;
+		l = snprintf(result, maxSize, "%s", (const char *)val);
+		break;
 	case SYN_PATH:{
 	        const Path_T* p = (const Path_T*)val;
-                if (strlen(p->volumeName)+strlen(p->path)+2+2+1>=maxSize)
-                        return NWE_BUFFER_OVERFLOW;
-		sprintf(result,"%u,%s,%s", p->nameSpaceType,p->volumeName, p->path);
+
+		l = snprintf(result, maxSize, "%u,%s,%s", p->nameSpaceType, p->volumeName, p->path);
                 }
 		break;
 	case SYN_TYPED_NAME:{
 		const Typed_Name_T* tn = (const Typed_Name_T*)val;
-                if (strlen(tn->objectName)+8+8+2+1>=maxSize)
-                        return NWE_BUFFER_OVERFLOW;
-		sprintf(result,"%u,%u,%s", tn->interval,tn->level,tn->objectName);
+
+		l = snprintf(result, maxSize, "%u,%u,%s", tn->interval, tn->level, tn->objectName);
 		}
 		break;
 	case SYN_FAX_NUMBER:{
 	        const Fax_Number_T* fn = (const Fax_Number_T*)val;
-                if (strlen(fn->telephoneNumber)+2+1+1>=maxSize)
-                        return NWE_BUFFER_OVERFLOW;
-		sprintf(result,"%s,%u", fn->telephoneNumber,fn->parameters.numOfBits);
+		
+		l = snprintf(result, maxSize, "%s,%u", fn->telephoneNumber, fn->parameters.numOfBits);
 		}
 		break;
 	case SYN_EMAIL_ADDRESS:{
 		const EMail_Address_T* ea = (const EMail_Address_T*)val;
                 /*change the SMTP:aaa@bbbb to SMTP,aaa@bbbb */
                 char* p=strchr(ea->address,':');
-                if (strlen(ea->address)+2+1+1>=maxSize)
-                        return NWE_BUFFER_OVERFLOW;
 
                 if (p) *p=',';
-		sprintf(result,"%u,%s", ea->type,ea->address);
+		l = snprintf(result, maxSize, "%u,%s", ea->type, ea->address);
 		}
 		break;
 	case SYN_PO_ADDRESS:{
 	        const NWDSChar* const* pa = (const NWDSChar* const*)val;
-                int n;
-                size_t len=1;
-                for (n=0;n <5;n++)
-                  len +=strlen(pa[n]+1);
-                if (len >=maxSize)
-                        return NWE_BUFFER_OVERFLOW;
-		sprintf(result,"%s,%s,%s,%s,%s,%s",pa[0],pa[1],pa[2],pa[3],pa[4],pa[5]);
+
+		l = snprintf(result, maxSize, "%s,%s,%s,%s,%s,%s", pa[0], pa[1], pa[2], pa[3], pa[4], pa[5]);
 		}
 		break;
 	case SYN_HOLD:{
 	        const Hold_T* h = (const Hold_T*)val;
-                if (strlen(h->objectName)+8+1+1>=maxSize)
-                        return NWE_BUFFER_OVERFLOW;
-		sprintf(result,"%u,%s", h->amount, h->objectName);
+
+		l = snprintf(result, maxSize, "%u,%s", h->amount, h->objectName);
 		}
 		break;
          case SYN_TIMESTAMP:{
                 const TimeStamp_T* stamp = (const TimeStamp_T*)val;
-                if (maxSize <=3*9)
-                        return NWE_BUFFER_OVERFLOW;
-                sprintf(result,"%u,%u,%u",stamp->wholeSeconds, stamp->replicaNum,stamp->eventID);
+                
+		l = snprintf(result, maxSize, "%u,%u,%u", stamp->wholeSeconds, stamp->replicaNum, stamp->eventID);
                 }
                 break;
          case SYN_BACK_LINK:{
                 const Back_Link_T* bl = (const Back_Link_T*)val;
-                if (strlen(bl->objectName)+8+1+1 >=maxSize)
-                        return NWE_BUFFER_OVERFLOW;
-                sprintf(result,"%08X,%s", bl->remoteID, bl->objectName);
+
+		l = snprintf(result, maxSize, "%08X,%s", bl->remoteID, bl->objectName);
                 }
                 break;
         case SYN_CI_LIST:{
@@ -949,61 +910,68 @@ static NWDSCCODE __docopy_string (NWDSContextHandle ctx, const void* val,
                 }
                 *(--aux)=0;
                 }
-		break;
+		return 0;
 
          case SYN_OCTET_LIST:{
                 const Octet_List_T* ol = (const Octet_List_T*)val;
                 size_t i;
-                char aux [4];
-                if ((ol->length+1)*3+1 >=maxSize)
+                char *aux;
+
+                if (20 + (ol->length+1)*3+1 >=maxSize)
                         return NWE_BUFFER_OVERFLOW;
-                sprintf(result,"%u", ol->length);
+                sprintf(result, "%u", ol->length);
+		aux = result + strlen(result);
                 for (i = 0; i < ol->length; i++) {
-                        sprintf(aux,",%02X", ol->data[i]);
-                        strcat(result,aux);
+                        sprintf(aux, ",%02X", ol->data[i]);
+                        aux += 3;
                 }
                 }
-                break;
+                return 0;
         case SYN_OCTET_STRING:{
                 const Octet_String_T* os = (const Octet_String_T*)val;
-                char aux [4];
                 size_t i;
+		char *aux;
 #ifdef DEBUG_PRINT
                 printf ("len %d\n",os->length);
 #endif
-                if ((os->length+1)*3+1 >=maxSize)
+                if (20 + (os->length+1)*3+1 >=maxSize)
                         return NWE_BUFFER_OVERFLOW;
-                sprintf(result,"%u", os->length);
+                sprintf(result, "%u", os->length);
+		aux = result + strlen(result);
                 for (i = 0; i < os->length; i++) {
-                        sprintf(aux,",%02X", os->data[i]);
-                        strcat(result,aux);
+                        sprintf(aux, ",%02X", os->data[i]);
+                        aux += 3;
                 }
                 }
-                break;
+                return 0;
         case SYN_NET_ADDRESS:{
                 const Net_Address_T* na = (const Net_Address_T*)val;
                 size_t z;
-                char aux[4];
+                char *aux;
+
                 z=na->addressLength;
-                if (3*(z+2)+1  >=maxSize)
+                if (40 + 3*(z+2)+1  >=maxSize)
                         return NWE_BUFFER_OVERFLOW;
-                sprintf(result,"%u,%u", na->addressType,na->addressLength);
+                sprintf(result, "%u,%u", na->addressType, na->addressLength);
+		aux = result + strlen(result);
                 for (z = 0; z < na->addressLength; z++) {
-                        sprintf(aux,",%02X", na->address[z]);
-                        strcat(result,aux);
+                        sprintf(aux, ",%02X", na->address[z]);
+			aux += 3;
                 }
                 }
-                break;
+                return 0;
         case SYN_OBJECT_ACL:{
                 const Object_ACL_T* oacl = (const Object_ACL_T*)val;
-                if (strlen(oacl->protectedAttrName)+strlen(oacl->subjectName)+8+2+1 >=maxSize)
-                        return NWE_BUFFER_OVERFLOW;
-                sprintf(result,"%s,%s,%08X",oacl->protectedAttrName,oacl->subjectName,oacl->privileges);
+
+		l = snprintf(result, maxSize, "%s,%s,%08X", oacl->protectedAttrName, oacl->subjectName, oacl->privileges);
                 }
                 break;
 	default:
 		return EINVAL;
 	}
+	if (l < 0 || (size_t)l >= maxSize) {
+		return NWE_BUFFER_OVERFLOW;
+	}
         return 0;
 }
 
@@ -1016,7 +984,7 @@ NWDSCCODE docopy_string(NWDSContextHandle ctx, const void * val, const enum SYNT
 
 
 static
-NWDSCCODE docopy_int(UNUSED(NWDSContextHandle ctx), const void * val, const enum SYNTAX synt, size_t currentSize,
+NWDSCCODE docopy_int(UNUSED(NWDSContextHandle ctx), const void * val, const enum SYNTAX synt, UNUSED(size_t currentSize),
 		     void * result, size_t maxSize) {
 #ifdef DEBUG_PRINT
 	printf ("docopy_int got :%s synt = %d cursize=%d maxsize= %d\n",(char *)val,synt,currentSize,maxSize );
@@ -1136,7 +1104,7 @@ static NWDSCCODE strlist_to_string (struct strlist * l, char ** result, char sep
 
 /* append the new string to a linked list */
 static NWDSCCODE docopy_multistring(NWDSContextHandle ctx, const void * val, const enum SYNTAX synt, size_t currentSize,
-				    void * result, size_t maxSize) {
+				    void * result, UNUSED(size_t maxSize)) {
 	NWDSCCODE err;
 	char tmpBuf[MAX_DN_BYTES+1];
 	struct strlist* l=(struct strlist *) result;
@@ -1328,9 +1296,11 @@ struct nw_home_info {
 };
 
 
-static NWDSCCODE docopy_host_server(NWDSContextHandle ctx,
-                                    const void* val, const enum SYNTAX synt,
-                                    size_t currentSize, void* result, size_t maxSize){
+/* Note that this function is completely wrong: host server is DN, and you should use DN operations on it...
+ * Cutting it at first dot is nonsense... It might work, but there is no reason why it should... */
+static NWDSCCODE docopy_host_server(UNUSED(NWDSContextHandle ctx),
+                                    const void* val, UNUSED(const enum SYNTAX synt),
+                                    UNUSED(size_t currentSize), void* result, UNUSED(size_t maxSize)) {
 	struct nw_home_info* hi = (struct nw_home_info*)result;
         char buf [MAX_DN_CHARS];
         char * dot;
@@ -1350,9 +1320,9 @@ static NWDSCCODE docopy_host_server(NWDSContextHandle ctx,
 	return 0;
 }
 
-static NWDSCCODE docopy_host_resource_name(NWDSContextHandle ctx,
-                                    const void* val, const enum SYNTAX synt,
-                                    size_t currentSize, void* result, size_t maxSize){
+static NWDSCCODE docopy_host_resource_name(UNUSED(NWDSContextHandle ctx),
+                                    const void* val, UNUSED(const enum SYNTAX synt),
+                                    UNUSED(size_t currentSize), void* result, UNUSED(size_t maxSize)) {
 	struct nw_home_info* hi = (struct nw_home_info*)result;
 
 
@@ -1369,14 +1339,13 @@ static NWDSCCODE docopy_host_resource_name(NWDSContextHandle ctx,
 	return 0;
 }
 
-static NWDSCCODE docopy_home_directory(NWDSContextHandle ctx,
-                                        const void* val, const enum SYNTAX synt,
-                                        size_t currentSize, void* result, size_t maxSize){
+static NWDSCCODE docopy_home_directory(UNUSED(NWDSContextHandle ctx),
+                                        const void* val, UNUSED(const enum SYNTAX synt),
+                                        UNUSED(size_t currentSize), void* result, UNUSED(size_t maxSize)) {
 
 
       const Path_T* pa = (const Path_T*) val;
       Path_T* result_int = (Path_T*)result;
-      NWDSCCODE dserr;
       char * v;
 
 
