@@ -110,7 +110,7 @@ long nds_get_tree_name(struct ncp_conn *conn, char *name, int name_buf_len) {
 
 /* for login */
 long nds_resolve_name(struct ncp_conn *conn, int flags, uni_char *entry_name, 
- int *entry_id, int *remote, struct sockaddr *serv_addr, size_t *addr_len) {
+ int *entry_id, int *remote, UNUSED(struct sockaddr *serv_addr), size_t *addr_len) {
 	NWDSCCODE err;
 	NWDSContextHandle ctx;
 	u_int32_t ctxflags;
