@@ -30,16 +30,11 @@
 						Added license.
  */
 
-#include "config.h"
 #include "ncplib_i.h"
 
 #include <string.h>
 #include <errno.h>
 
-#include <libintl.h>
-#define _(X) dgettext(PACKAGE, (X))
-#define N_(X) (X)
-
 #ifndef ENOPKG
 #define ENOPKG	ENOSYS
 #endif
@@ -47,6 +42,31 @@
 /* Here the ncp calls begin
  */
 
+static inline void ncp_queue_job_2_out(struct nw_queue_job_entry *j) {
+	j->JobNumber = DVAL_LH(&j->JobNumber, 0);
+}
+
+static inline void ncp_add_queue_job(struct ncp_conn *conn, const struct nw_queue_job_entry *j) {
+	memcpy(conn->current_point, j, sizeof(*j));
+	ncp_queue_job_2_out((struct nw_queue_job_entry*)conn->current_point);
+	conn->current_point += sizeof(*j);
+}
+
+static void ncp_reply_queue_entry(struct nw_queue_job_entry *j, const void * reply, size_t replys) {
+	memcpy(j, reply, replys);
+	if (replys < sizeof(*j)) {
+		unsigned char * v = (unsigned char*)j;
+		
+		memset(v + replys, 0, sizeof(*j) - replys);
+	}
+	ncp_queue_job_2_out(j);
+}
+
+static inline void ncp_reply_queue_job(struct queue_job *job, const void * reply, size_t replys) {
+	ncp_reply_queue_entry(&job->j, reply, replys);
+	ConvertToNWfromDWORD(job->j.JobFileHandle, job->file_handle);
+}
+
 /* Create a new job entry */
 long
 ncp_create_queue_job_and_file(struct ncp_conn *conn,
@@ -57,16 +77,14 @@ ncp_create_queue_job_and_file(struct ncp_conn *conn,
 
 	ncp_init_request_s(conn, 121);
 	ncp_add_dword_hl(conn, queue_id);
-	ncp_add_mem(conn, &(job->j), sizeof(job->j));
+	ncp_add_queue_job(conn, &job->j);
 
 	if ((result = ncp_request(conn, 23)) != 0)
 	{
 		ncp_unlock_conn(conn);
 		return result;
 	}
-	memcpy(&(job->j), ncp_reply_data(conn, 0), 78);
-	ConvertToNWfromDWORD(job->j.JobFileHandle, job->file_handle);
-
+	ncp_reply_queue_job(job, ncp_reply_data(conn, 0), 78);
 	ncp_unlock_conn(conn);
 	return 0;
 }
@@ -74,7 +92,7 @@ ncp_create_queue_job_and_file(struct ncp_conn *conn,
 long
 ncp_close_file_and_start_job(struct ncp_conn *conn,
 			     u_int32_t queue_id,
-			     struct queue_job *job)
+			     const struct queue_job *job)
 {
 	long result;
 
@@ -130,9 +148,7 @@ ncp_service_queue_job(struct ncp_conn *conn, u_int32_t queue_id, u_int16_t job_t
 		ncp_unlock_conn(conn);
 		return result;
 	}
-	memcpy(&(job->j), ncp_reply_data(conn, 0), 78);
-	ConvertToNWfromDWORD(job->j.JobFileHandle, job->file_handle);
-
+	ncp_reply_queue_job(job, ncp_reply_data(conn, 0), 78);
 	ncp_unlock_conn(conn);
 	return 0;
 }
@@ -153,6 +169,25 @@ ncp_finish_servicing_job(struct ncp_conn *conn, u_int32_t queue_id,
 	return result;
 }
 
+long
+ncp_change_job_position(struct ncp_conn *conn, NWObjectID queue_id,
+			 u_int32_t job_number, unsigned int position)
+{
+	long result;
+
+	if (position > 255) {
+		position = 255;
+	}
+	ncp_init_request_s(conn, 110);
+	ncp_add_dword_hl(conn, queue_id);
+	ncp_add_word_lh(conn, job_number);
+	ncp_add_byte(conn, position);
+
+	result = ncp_request(conn, 23);
+	ncp_unlock_conn(conn);
+	return result;
+}
+
 long
 ncp_abort_servicing_job(struct ncp_conn *conn, u_int32_t queue_id,
 			u_int32_t job_number)
@@ -189,7 +224,6 @@ ncp_get_queue_length(struct ncp_conn *conn,
 
 	if (ncp_reply_dword_hl(conn,0) != queue_id)
 	{
-		printf(_("Ouch! Server didn't reply with same queue id in ncp_get_queue_length!\n"));
 		result=-EINVAL;
 	}
 	else
@@ -224,8 +258,7 @@ ncp_get_queue_job_ids(struct ncp_conn *conn,
 	}
 
 	*length2 = ncp_reply_dword_lh(conn,4);
-	if (conn->ncp_reply_size < 8 + 4*(*length2))
-	{
+	if (conn->ncp_reply_size < 8 + 4*(*length2)) {
 		result=NWE_INVALID_NCP_PACKET_LENGTH;
 		goto out;
 	}
@@ -259,12 +292,11 @@ ncp_get_queue_job_info(struct ncp_conn *conn,
 	if ((result = ncp_request(conn, 23)) != 0)
 		goto out;
 
-	if (conn->ncp_reply_size < sizeof(struct nw_queue_job_entry))
-	{
+	if (conn->ncp_reply_size < sizeof(struct nw_queue_job_entry)) {
 		result=NWE_INVALID_NCP_PACKET_LENGTH;
-	}    
-	else
-		memcpy(jobdata,ncp_reply_data(conn,0), sizeof(struct nw_queue_job_entry));
+	} else {
+		ncp_reply_queue_entry(jobdata, ncp_reply_data(conn,0), sizeof(struct nw_queue_job_entry));
+	}
 
 out:
 	ncp_unlock_conn(conn);
@@ -288,3 +320,17 @@ NWRemoveJobFromQueue2
 	return result;
 }
 
+NWCCODE
+NWChangeQueueJobEntry(NWCONN_HANDLE conn,
+		      NWObjectID queue_id,
+		      const struct nw_queue_job_entry *jobdata)
+{
+	NWCCODE result;
+
+	ncp_init_request_s(conn, 123);
+	ncp_add_dword_hl(conn, queue_id);
+	ncp_add_queue_job(conn, jobdata);
+	result = ncp_request(conn, 23);
+	ncp_unlock_conn(conn);
+	return result;
+}
