@@ -42,6 +42,10 @@
 #include "ncpcode.h"
 #include "ncpi.h"
 
+static NWCCODE NWCCOpenConnByNameTran(NWCONN_HANDLE startConn, const char *serverName,
+		nuint nameFormat, nuint openState, nuint reserved, 
+		nuint transport, NWCONN_HANDLE* pconn);
+
 struct resolver {
 	const char* name;
 	NWCCODE (*start)(void **rh, NWCONN_HANDLE conn,
@@ -113,7 +117,13 @@ static NWCCODE bind_start(void **prh, NWCONN_HANDLE startConn,
 	if (!startConn) {
 		err = ncp_next_conn(NULL, &startConn);
 		if (err) {
-			return err;
+			if (name != NULL || nameFormat != NWCC_NAME_FORMAT_BIND || transport != NT_IPX) {
+				err = NWCCOpenConnByNameTran(NULL, NULL, NWCC_NAME_FORMAT_BIND,
+					NWCC_OPEN_NEW_CONN, NWCC_RESERVED, NT_IPX, &startConn);
+			}
+			if (err) {
+				return err;
+			}
 		}
 	} else {
 		ncp_conn_use(startConn);
@@ -259,7 +269,7 @@ struct dns_rh {
 	u_int32_t addresses[0];
 };
 
-static NWCCODE dns_start(void **prh, NWCONN_HANDLE startConn,
+static NWCCODE dns_start(void **prh, UNUSED(NWCONN_HANDLE startConn),
 			 const char *name, nuint nameFormat, nuint transport) {
 	struct dns_rh* rh;
 	struct hostent* he;
@@ -554,7 +564,7 @@ static void sap_process(int fd, unsigned char *sap_request, size_t cmplen) {
 			while (1) {
 				long err;
 				int recvtime;
-				int offs;
+				size_t offs;
 
 				if (gettimeofday(&tv, NULL))
 					goto quitSock;
@@ -597,8 +607,8 @@ quit:
 	write(fd, &u32, sizeof(u32));
 }
 
-static NWCCODE sap_start(void **prh, NWCONN_HANDLE startConn,
-			  const char *name, nuint nameFormat, nuint transport) {
+static NWCCODE sap_start(void **prh, UNUSED(NWCONN_HANDLE startConn),
+			 const char *name, nuint nameFormat, nuint transport) {
 	struct sap_rh* rh;
 	unsigned char sap_request[60];
 	size_t cmplen;
@@ -867,18 +877,26 @@ NWCCODE ncp_find_server_addr(const char **serverName, int object_type, struct so
 		if (!err) {
 			if (ta.type == NT_IPX) {
 				struct sockaddr_ipx* ipx = (struct sockaddr_ipx*)addr;
-				
-				ipx->sipx_family = AF_IPX;
-				memcpy(ipx->sipx_node, buffer + 4, 6);
-				memcpy(&ipx->sipx_network, buffer, 4);
-				memcpy(&ipx->sipx_port, buffer + 10, 2);
-				ipx->sipx_type = 0x11;
+			
+				if (len < sizeof(*ipx)) {
+					err = NWE_BUFFER_OVERFLOW;
+				} else {
+					ipx->sipx_family = AF_IPX;
+					memcpy(ipx->sipx_node, buffer + 4, 6);
+					memcpy(&ipx->sipx_network, buffer, 4);
+					memcpy(&ipx->sipx_port, buffer + 10, 2);
+					ipx->sipx_type = 0x11;
+				}
 			} else if (ta.type == NT_UDP || ta.type == NT_TCP) {
 				struct sockaddr_in* in = (struct sockaddr_in*)addr;
-				
-				in->sin_family = AF_INET;
-				memcpy(&in->sin_addr.s_addr, buffer + 2, 4);
-				memcpy(&in->sin_port, buffer, 2);
+
+				if (len < sizeof(*in)) {
+					err = NWE_BUFFER_OVERFLOW;
+				} else {
+					in->sin_family = AF_INET;
+					memcpy(&in->sin_addr.s_addr, buffer + 2, 4);
+					memcpy(&in->sin_port, buffer, 2);
+				}
 			} else {
 				err = EINVAL;
 			}
