@@ -3,7 +3,7 @@
 #ifndef USUALS /* Assures no redefinitions of usual types...*/
 #define USUALS
 
-#include <sys/types.h>
+#include <ncp/kernel/types.h>
 
 typedef unsigned char boolean;	/* values are TRUE or FALSE */
 typedef u_int8_t byte;	/* values are 0-255 */
