@@ -219,8 +219,12 @@ static int load_ncpfs(void)
 		return 1;
 	} else if (pid == 0)
 	{
+		char *myenv[] = {
+			"PATH=/sbin:/usr/sbin:/bin:/usr/bin",
+			NULL
+		};
 		/* child */
-		execl("/sbin/modprobe", "modprobe", "ncpfs", NULL);
+		execle("/sbin/modprobe", "modprobe", "ncpfs", NULL, myenv);
 		_exit(127);	/* execl error */
 	} else
 	{
@@ -355,6 +359,54 @@ void verify_argv(int argc, char* argv[]) {
 
 #endif 
 
+static inline int ncpm_suser(void) {
+	return setreuid(-1, 0);
+}
+
+static int ncpm_normal(void) {
+	int e;
+	int v;
+
+	e = errno;
+	v = setreuid(-1, myuid);
+	errno = e;
+	return v;
+}
+
+static int proc_ncpm_mount(const char* source, const char* target, const char* filesystem, unsigned long mountflags, const void* data) {
+	int v;
+	int e;
+
+	if (ncpm_suser()) {
+		return errno;
+	}
+	v = mount(source, target, filesystem, mountflags, data);
+	if (ncpm_normal()) {
+		/* We cannot handle this situation gracefully, so do what we can */
+
+		e = errno;
+		/* If mount suceeded, undo it */
+		if (v) {
+			umount(target);
+		}
+		errexit(88, _("Cannot relinquish superuser rights: %s\n"), strerror(e));
+	}
+	return v;
+}
+
+int proc_ncpm_umount(const char* target) {
+	int v;
+
+	if (ncpm_suser()) {
+		return errno;
+	}
+	v = umount(target);
+	if (ncpm_normal()) {
+		errexit(89, _("Cannot relinquish superuser rights: %s\n"), strerror(errno));
+	}
+	return v;
+}
+
 #ifdef MOUNT2
 static int ncp_mount_v2(const char* mount_name, unsigned long flags, const struct ncp_mount_data_independent* data) {
 	struct ncp_mount_data_v2 datav2;
@@ -392,7 +444,7 @@ static int ncp_mount_v2(const char* mount_name, unsigned long flags, const struc
 	}
         datav2.file_mode   = data->file_mode;
         datav2.dir_mode    = data->dir_mode;
-	err = mount(mount_name, data->mount_point, "ncpfs", flags, (void*) &datav2);
+	err = proc_ncpm_mount(mount_name, data->mount_point, "ncpfs", flags, (void*) &datav2);
 	if (err)
 		return errno;
 	return 0;
@@ -456,7 +508,7 @@ static int ncp_mount_v3(const char* mount_name, unsigned long flags, const struc
 		exit(0);	/* Should not return from process_connection */
 	}
 	close(pp[0]);
-	err=mount(mount_name, data->mount_point, "ncpfs", flags, (void*) &datav3);
+	err=proc_ncpm_mount(mount_name, data->mount_point, "ncpfs", flags, (void*) &datav3);
 	if (err) {
 		err = errno;
 		/* Mount unsuccesful so we have to kill daemon */
@@ -507,7 +559,7 @@ static int ncp_mount_v4(const char* mount_name, unsigned long flags, struct ncp_
 		sprintf(mountopts, "version=%u,flags=%u,owner=%u,uid=%u,gid=%u,mode=%u,dirmode=%u,timeout=%u,retry=%u,wdogpid=%u,ncpfd=%u,infofd=%u",
 			NCP_MOUNT_VERSION_V5, ncpflags, data->mounted_uid, data->uid, data->gid, data->file_mode,
 			data->dir_mode, data->time_out, data->retry_count, wdog_pid, data->ncp_fd, pp[1]);
-		err=mount(mount_name, data->mount_point, "ncpfs", flags, mountopts);
+		err=proc_ncpm_mount(mount_name, data->mount_point, "ncpfs", flags, mountopts);
 	} else {
 		err=-1;
 	}
@@ -525,7 +577,7 @@ static int ncp_mount_v4(const char* mount_name, unsigned long flags, struct ncp_
 	        datav4.file_mode   = data->file_mode;
         	datav4.dir_mode    = data->dir_mode;
 		datav4.wdog_pid	   = wdog_pid;
-		err = mount(mount_name, data->mount_point, "ncpfs", flags, (void*)&datav4);
+		err = proc_ncpm_mount(mount_name, data->mount_point, "ncpfs", flags, (void*)&datav4);
 		if (err) {
 			err = errno;
 			/* Mount unsuccesful so we have to kill daemon */
@@ -546,9 +598,16 @@ static int ncp_mount_v4(const char* mount_name, unsigned long flags, struct ncp_
 void init_mount_info(struct ncp_mount_info *info) {
 	mode_t um;
 
-	memset(info, 0, sizeof(*info));
-
 	myuid = getuid();
+	myeuid = geteuid();
+
+	if (myeuid == 0) {
+		if (setreuid(-1, myuid)) {
+			errexit(87, _("Cannot relinquish superuser rights: %s\n"), strerror(errno));
+		}
+	}
+
+	memset(info, 0, sizeof(*info));
 
 	info->version = -1;
 	info->flags = MS_MGC_VAL;
@@ -649,7 +708,14 @@ ncp_mount_specific(struct ncp_conn* conn, int pathNS, const unsigned char* NWpat
 			sr.name_space = NW_NS_DOS;
 			sr.dirEntNum = DVAL_LH(&dirinfo.Directory.dirEntNum, 0);
 		}
+		if (ncpm_suser()) {
+			return -errno;
+		}
 		result = ioctl(ncp_get_fid(conn), NCP_IOC_SETROOT, &sr);
+		if (ncpm_normal()) {
+			/* Just continue, otherwise we cannot unmount directory */
+			return result ? -errno : -EPERM;
+		}
 		if (!result) {
 			return 0;
 		}
@@ -665,7 +731,15 @@ ncp_mount_specific(struct ncp_conn* conn, int pathNS, const unsigned char* NWpat
 #endif
 		return -ENOPKG;
 	}
-	if (ioctl(ncp_get_fid(conn), NCP_IOC_CONN_LOGGED_IN, NULL) != 0) {
+	if (ncpm_suser()) {
+		return -errno;
+	}
+	result = ioctl(ncp_get_fid(conn), NCP_IOC_CONN_LOGGED_IN, NULL);
+	if (ncpm_normal()) {
+		/* Just continue, otherwise we cannot umount directory */
+		return result ? -errno : -EPERM;
+	}
+	if (result != 0) {
 		return -errno;
 	}
 	return 0;
@@ -754,7 +828,7 @@ process_wdog_packet (int wdog_fd)
 	sendto(wdog_fd, buf, 2, 0, (struct sockaddr *) &sender, addrlen);
 }
 
-static void reapChld(int dummy) {
+static void reapChld(UNUSED(int dummy)) {
 	signal(SIGCHLD, reapChld);
 	/* reap all exited childrens... */
 	while (wait4(-1, NULL, WNOHANG, NULL) > 0) ;
@@ -798,11 +872,14 @@ static void ncp_ctl_cmd(unsigned int cmd, const unsigned char* data, size_t data
 			return;
 	}
 	{
-		char xxx[1024];
+		char xxx[1024]; /* "cmd=XXXXXXXXXXX, len=XXXXXXXXX, data:" + 3x300 chars */
 		char* p;
 
 		sprintf(xxx, "cmd=%u, len=%u, data:", cmd, datalen);
 		p = xxx + strlen(xxx);
+		if (datalen > 300) {
+			datalen = 300;
+		}
 		while (datalen--) {
 			sprintf(p, " %02X", *data++);
 			p += 3;
@@ -975,7 +1052,7 @@ static int getconn(NWCONN_HANDLE* cn) {
 	return ncp_open_mount(nwcc_mount_point, cn);
 }
 
-static int ncp_ext_perform(struct ncp_ext_client* clnt, const unsigned char* data, size_t rqlen) {
+static int ncp_ext_perform(struct ncp_ext_client* clnt, UNUSED(const unsigned char* data), UNUSED(size_t rqlen)) {
 	NWCONN_HANDLE cn;
 	int err;
 
@@ -1341,7 +1418,7 @@ void add_mnt_entry(char* mount_name, char* mpnt, unsigned long flags) {
 
 	ment.mnt_fsname = mount_name;
 	ment.mnt_dir = mpnt;
-	ment.mnt_type = "ncpfs";
+	ment.mnt_type = (char*)"ncpfs";
 	ment.mnt_opts = mnt_opts;
 	ment.mnt_freq = 0;
 	ment.mnt_passno = 0;
@@ -1358,6 +1435,9 @@ void add_mnt_entry(char* mount_name, char* mpnt, unsigned long flags) {
 	}
 	*p = 0;
 
+	if (ncpm_suser()) {
+		errexit(91, _("Cannot switch to superuser: %s\n"), strerror(errno));
+	}
 	if ((fd = open(MOUNTED "~", O_RDWR | O_CREAT | O_EXCL, 0600)) == -1)
 	{
 		errexit(58, _("Can't get %s~ lock file\n"), MOUNTED);
@@ -1382,6 +1462,9 @@ void add_mnt_entry(char* mount_name, char* mpnt, unsigned long flags) {
 	{
 		errexit(62, _("Can't remove %s~\n"), MOUNTED);
 	}
+	if (ncpm_normal()) {
+		errexit(90, _("Cannot relinquish superuser rights: %s\n"), strerror(EPERM));
+	}
 }
 
 static int __proc_option(const struct optinfo* opts, struct ncp_mount_info* info, const char* opt, const char* param) {
@@ -1446,7 +1529,7 @@ static void opt_clear_noexec(struct ncp_mount_info* info, unsigned int param) {
 }
 
 static void opt_remount(struct ncp_mount_info* info, unsigned int param) __attribute__((noreturn));
-static void opt_remount(struct ncp_mount_info* info, unsigned int param) {
+static void opt_remount(UNUSED(struct ncp_mount_info* info), UNUSED(unsigned int param)) {
 	errexit(7, _("Remounting not supported, sorry\n"));
 }
 
@@ -1549,7 +1632,7 @@ static void opt_set_codepage(struct ncp_mount_info* info, const char* param) {
 	strcpy(info->nls_cs.codepage, param);
 }
 
-static void opt_not_implemented(struct ncp_mount_info* info, unsigned int param) {
+static void opt_not_implemented(UNUSED(struct ncp_mount_info* info), UNUSED(unsigned int param)) {
 	/* noop */
 }
 
@@ -1635,6 +1718,10 @@ int proc_aftermount(const struct ncp_mount_info* info, NWCONN_HANDLE* pconn) {
 	if ((info->nls_cs.codepage[0] != 0) || (info->nls_cs.iocharset[0] != 0)) {
 		int i;
 		
+		if (ncpm_suser()) {
+			fprintf(stderr, _("Cannot switch to superuser: %s\n"), strerror(errno));
+			return 90;
+		}
 		i = ioctl(ncp_get_fid(conn), NCP_IOC_SETCHARSETS,  &info->nls_cs);
 		if (i && (errno == EINVAL)) {
 			struct ncp_nls_ioctl_old old_nls;
@@ -1646,6 +1733,10 @@ int proc_aftermount(const struct ncp_mount_info* info, NWCONN_HANDLE* pconn) {
 			strcpy(old_nls.iocharset, info->nls_cs.iocharset);
 			i = ioctl(ncp_get_fid(conn), NCP_IOC_SETCHARSETS_OLD, &old_nls);
 		}
+		if (ncpm_normal()) {
+			fprintf(stderr, _("Cannot relinquish superuser rights: %s\n"), strerror(-errno));
+			return 91;
+		}
 		if (i) {
 			if (errno == EINVAL || errno == ENOTTY) {
 				fprintf(stderr, _("Your kernel does not support character mapping. You should upgrade to latest version.\n"));
