@@ -16,6 +16,7 @@
 #include "ncpmount.h"       
 
 uid_t myuid;
+uid_t myeuid;
 char *progname;
 char mount_point[MAXPATHLEN + 1];
 
@@ -118,5 +119,8 @@ struct optinfo {
 void proc_option(const struct optinfo* opts, struct ncp_mount_info* info, const char* opt, const char* param);
 int proc_buildconn(struct ncp_mount_info* info);
 int proc_aftermount(const struct ncp_mount_info* info, NWCONN_HANDLE* conn);
+int proc_ncpm_umount(const char* dir);
+
+#define UNUSED(x)	x __attribute__((unused))
 
 #endif	/* __NCPM_COMMON_H__ */
