@@ -90,6 +90,8 @@
 
  */
 
+#define NCP_OBSOLETE
+
 #include "ncpm_common.h"
 #include "mount_login.h"
 
@@ -169,7 +171,7 @@ main(int argc, char *argv[])
 {
 	struct ncp_mount_info info;
 	struct stat st;
-	char mount_name[256];
+	char *mount_name;
 #ifdef NDS_SUPPORT
 	NWDSContextHandle ctx;
 	NWCONN_HANDLE auth_conn;
@@ -348,7 +350,7 @@ main(int argc, char *argv[])
 	if (info.server && info.tree) {
 		errexit(66, _("Both tree and server name were specified. It is not allowed.\n"));
 	}
-	if (geteuid() != 0)
+	if (myeuid != 0)
 	{
 		errexit(26, _("%s must be installed suid root\n"), progname);
 	}
@@ -431,11 +433,14 @@ main(int argc, char *argv[])
 #endif
 	{
 		if (info.volume) {
-			info.pathlen = ncp_path_to_NW_format(info.volume, info.NWpath, sizeof(info.NWpath));
+			int ln;
+
+			ln = ncp_path_to_NW_format(info.volume, info.NWpath, sizeof(info.NWpath));
 			info.remote_path = info.volume;
-			if (info.pathlen < 0) {
-				errexit(18, _("Volume path `%s' is invalid: `%s'\n"), info.volume, strerror(-info.pathlen));
+			if (ln < 0) {
+				errexit(18, _("Volume path `%s' is invalid: `%s'\n"), info.volume, strerror(-ln));
 			};
+			info.pathlen = ln;
 			if (info.pathlen == 1) {
 				info.mdata.mounted_vol = "";
 				info.remote_path = "/";
@@ -550,7 +555,9 @@ main(int argc, char *argv[])
 	} else 
 #endif	/* CONFIG_NATIVE_IP */
 	{
+#if defined(CONFIG_NATIVE_UNIX) && !defined(CONFIG_NATIVE_IP)
 ncpipx:;
+#endif
 		if ((!info.allow_multiple_connections)&&
 		    ((tmp_mount = ncp_find_permanent(&spec)) != NULL))
 		{
@@ -587,13 +594,18 @@ ncpipx:;
 
 	info.mdata.mount_point = mount_point;
 
-	strcpy(mount_name, spec.server);
-	strcat(mount_name, "/");
-	strcat(mount_name, spec.user);
+	if (asprintf(&mount_name, "%s/%s", spec.server, spec.user) < 0) {
+		NWDSFreeContext(ctx);
+		if (auth_conn) {
+			NWCCCloseConn(auth_conn);
+		}
+		errexit(85, _("Cannot allocate memory for mtab entry: %s\n"), strerror(ENOMEM));
+	}
 
 	result = ncp_mount(mount_name, &info);
 	if (result)
 	{
+		free(mount_name);
 		NWDSFreeContext(ctx);
 		if (auth_conn) {
 			NWCCCloseConn(auth_conn);
@@ -603,7 +615,8 @@ ncpipx:;
 	}
 	err = proc_aftermount(&info, &conn);
 	if (err) {
-		umount(info.mdata.mount_point);
+		proc_ncpm_umount(info.mdata.mount_point);
+		free(mount_name);
 		NWDSFreeContext(ctx);
 		if (auth_conn) {
 			NWCCCloseConn(auth_conn);
@@ -614,6 +627,8 @@ ncpipx:;
 	if (info.auth_src != NULL) {
 		err = NWDSAuthenticateConn(ctx, conn);
 		if (err) {
+			proc_ncpm_umount(info.mdata.mount_point);
+			free(mount_name);
 			NWDSFreeContext(ctx);
 			if (auth_conn) {
 				NWCCCloseConn(auth_conn);
@@ -629,7 +644,8 @@ ncpipx:;
 				mycom_err(err, _("in nds login"));
 				fprintf(stderr, _("Login denied.\n"));
 				ncp_close(conn);
-				umount(mount_point);
+				proc_ncpm_umount(mount_point);
+				free(mount_name);
 				NWDSFreeContext(ctx);
 				if (auth_conn) {
 					NWCCCloseConn(auth_conn);
@@ -653,7 +669,8 @@ ncpipx:;
 			mycom_err(err, _("in login"));
 			fprintf(stderr, _("Login denied\n"));
 			ncp_close(conn);
-			umount(mount_point);
+			proc_ncpm_umount(mount_point);
+			free(mount_name);
 			NWDSFreeContext(ctx);
 			if (auth_conn) {
 				NWCCCloseConn(auth_conn);
@@ -675,6 +692,9 @@ ncpipx:;
 #endif
 	err = NWDSFreeContext(ctx);
 	if (err) {
+		ncp_close(conn);
+		proc_ncpm_umount(mount_point);
+		free(mount_name);
 		if (auth_conn) {
 			NWCCCloseConn(auth_conn);
 		}
@@ -687,7 +707,8 @@ ncpipx:;
 	if ((err = ncp_mount_specific(conn, -1, info.NWpath, info.pathlen)) != 0) 
 	{
 		ncp_close(conn);
-		umount(mount_point);
+		proc_ncpm_umount(mount_point);
+		free(mount_name);
 		errexit(57, _("Cannot access path \"%s\": %s\n"), info.remote_path, strerror(-err));
 	}
 	ncp_close(conn);
