@@ -56,6 +56,7 @@ struct ncp_mount_data_v2 {
 #define NCP_MOUNT3_NO_NFS	0x0010
 #define NCP_MOUNT3_EXTRAS	0x0020
 #define NCP_MOUNT3_SYMLINKS	0x0040
+#define NCP_MOUNT3_NFS_EXTRAS	0x0080
 
 struct ncp_mount_data_v3 {
 	int version;
@@ -100,4 +101,6 @@ struct ncp_mount_data_v4 {
 	unsigned long dir_mode;
 };
 
+#define NCP_MOUNT_VERSION_V5	(5)
+
 #endif /* __NCPMOUNT_H__ */
