@@ -39,7 +39,7 @@
 #include <netinet/in.h>
 #include <errno.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
