@@ -34,8 +34,6 @@
 
 */
 
-#include "config.h"
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -43,7 +41,7 @@
 #include <string.h>
 #include <ncp/nwcalls.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 #define N_(X) (X)
 
@@ -154,8 +152,8 @@ main(int argc, char **argv)
 	int last_opt = 0;
 	
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 
 	program_name = argv[0];
 		
@@ -234,15 +232,15 @@ main(int argc, char **argv)
 	/*-------------------------------------------------------*/
 	if (!adminmode) {
 		char username[1000];
-		NWCCODE err;
+		NWCCODE err2;
 		const char* uptr = username;
 		char* tmessage = message;
 		message = (char *) malloc (300 * sizeof (char));
 		message[0] = '\0';
 
-		err = NWCCGetConnInfo(conn, NWCC_INFO_USER_NAME, 
+		err2 = NWCCGetConnInfo(conn, NWCC_INFO_USER_NAME, 
 			sizeof(username), username);
-		if (err)
+		if (err2)
 			uptr = "?";
 
 		snprintf(message, 300, _("From %s[%d]: %s"), uptr, 
@@ -301,7 +299,7 @@ main(int argc, char **argv)
 						if ((err = ncp_get_bindery_object_name(conn, user_id, &user)) != 0) {
 							/* skip NDS members :-( */
 							fprintf(stderr, _("%s: Cannot convert member ID 0x%08lX to name: %s\n"),
-									program_name, user_id, strnwerror(err));
+									program_name, (unsigned long)user_id, strnwerror(err));
 						} else {
 							perform_send(conn, message, user.object_name, user.object_type);
 						}
