@@ -76,15 +76,6 @@ main(int argc, char *argv[])
 	char *object_name = NULL;
 	char *object_pwd = NULL;
 	int object_type = NCP_BINDERY_USER;
-	union {
-		struct sockaddr any;
-#ifdef CONFIG_NATIVE_IPX
-		struct sockaddr_ipx ipx;
-#endif
-#ifdef CONFIG_NATIVE_IP
-		struct sockaddr_in inet;
-#endif
-		} addr;
 	long err;
 	int prterr;
 	
@@ -136,7 +127,7 @@ main(int argc, char *argv[])
 	}
 
 	err = ncp_find_conn_spec3(server, object_name, "",
-				  1, daemon ? ~0 : getuid(), 0, &spec);
+				  1, daemon ? ~0U : getuid(), 0, &spec);
 
 	if (err)
 	{
