@@ -22,16 +22,18 @@
 	0.00  1996			Volker Lendecke
 		Initial revision.
 
- */
+	1.00  2001, May 31		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Add include strings.h.
 
-#include "config.h"
+ */
 
 #include <ncp/ncplib.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
+#include <strings.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -107,8 +109,8 @@ main(int argc, char *argv[])
 	int opt;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
