@@ -230,6 +230,10 @@ static void doID(NWCONN_HANDLE conn, nuint32 id) {
 	}
 }
 
+static inline size_t my_strftime(char *s, size_t max, const char *fmt, const struct tm *tm) {
+	return strftime(s, max, fmt, tm);
+}
+
 static void dodate(nuint date) {
 	static const time_t zero_time_t = 0;
 	struct tm* tm;
@@ -240,7 +244,7 @@ static void dodate(nuint date) {
 	tm->tm_mon = ((date>>5) & 0xF) - 1;
 	tm->tm_mday = date & 0x1F;
 	tm->tm_isdst = 0;
-	strftime(text, sizeof(text), "%x", tm);
+	my_strftime(text, sizeof(text), "%x", tm);
 	printf("%s", text);
 }
 
@@ -254,7 +258,7 @@ static void dotime(nuint dtime) {
 	tm->tm_min = (dtime >> 5) & 0x3F;
 	tm->tm_sec = (dtime << 1) & 0x3F;
 	tm->tm_isdst = 0;
-	strftime(text, sizeof(text), "%X", tm);
+	my_strftime(text, sizeof(text), "%X", tm);
 	printf("%s", text);
 }
 
@@ -892,7 +896,7 @@ int main(int argc, char* argv[]) {
 	if (i < argc) {
 		path = argv[i++];
 	} else {
-		path = ".";
+		path = (char*)".";
 	}
 	err = NWCallsInit(NULL, NULL);
 	if (err) {
