@@ -31,8 +31,6 @@
 
  */
 
-#include "config.h"
-
 #include <unistd.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -40,7 +38,7 @@
 #include <ncp/nwcalls.h>
 #include <ncp/nwnet.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -90,8 +88,8 @@ main(int argc, char *argv[])
 	int opt;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
@@ -135,7 +133,7 @@ main(int argc, char *argv[])
 	}
 
 	if (useConn) {
-		char* path;
+		const char* path;
 
 		if (optind < argc)
 			path = argv[optind++];
