@@ -114,6 +114,11 @@ print_info(struct ncp_file_server_info_2 *info) {
 	return;
 }
 
+static inline size_t my_strftime(char *s, size_t max, const char *fmt, const struct tm *tm) {
+	return strftime(s, max, fmt, tm);
+}
+
+
 int
 main(int argc, char **argv)
 {
@@ -183,7 +188,7 @@ main(int argc, char **argv)
 					struct tm* tm;
 					
 					tm = localtime(&t);
-					strftime(text_server_time, sizeof(text_server_time), "%c", tm);
+					my_strftime(text_server_time, sizeof(text_server_time), "%c", tm);
 					printf("%s\n", text_server_time);
 				}
 				break;
