@@ -29,15 +29,13 @@
 		Wait for second to roll over for more accurate time.
  */
 
-#include "config.h"
-
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/time.h>
 
 #include <ncp/ncplib.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -67,6 +65,10 @@ help(void)
 	       "\n"));
 }
 
+static inline size_t my_strftime(char *s, size_t max, const char *fmt, const struct tm *tm) {
+	return strftime(s, max, fmt, tm);
+}
+
 int
 main(int argc, char **argv)
 {
@@ -78,8 +80,8 @@ main(int argc, char **argv)
 	struct timeval timeval;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
@@ -155,7 +157,7 @@ main(int argc, char **argv)
 			struct tm* tm;
 			
 			tm = localtime(&t);
-			strftime(text_server_time, sizeof(text_server_time), "%c", tm);
+			my_strftime(text_server_time, sizeof(text_server_time), "%c", tm);
 			printf("%s\n", text_server_time);
 		}
 	}
