@@ -31,16 +31,23 @@
 	1.01  2000, May 17		Bruce Richardson <brichardson@lineone.net>
 		Added rights string alternative for -r
   
+  	1.02  2000, August 14		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Added DS object resolve (on request from Mike Richichi <mrichich@drew.edu>)
+
+	1.03  2000, October 28		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Changed some constants to symbolic names (SA_*, NCP_DIRSTYLE_*).
+
  */
 
 #include "config.h"
 
 #include <ncp/nwcalls.h>
+#include <ncp/nwnet.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -81,7 +88,7 @@ main(int argc, char *argv[])
 	struct ncp_bindery_object o;
 	u_int16_t rights = ~0;
 	int perr = 0;
-	char *path = NULL;
+	const char *path = NULL;
 	long err;
 	int result = 1;
 	int opt;
@@ -93,8 +100,8 @@ main(int argc, char *argv[])
 	NWCCODE nwerr;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
@@ -130,12 +137,6 @@ main(int argc, char *argv[])
 		}
 	}
 
-	if (object_type < 0)
-	{
-		fprintf(stderr, _("%s: You must specify an object type\n"),
-			argv[0]);
-		goto finished;
-	}
 	if (object_name == NULL)
 	{
 		fprintf(stderr, _("%s: You must specify an object name\n"),
@@ -180,11 +181,43 @@ main(int argc, char *argv[])
 		path = volume;
 	}
 
-	if ((nwerr = ncp_get_bindery_object_id(conn, object_type, object_name, &o)) != 0)
-	{
+	if (object_type < 0) {
+#ifdef NDS_SUPPORT
+		u_int32_t flags;
+		NWDSContextHandle ctx;
+		
+		nwerr = NWDSCreateContextHandle(&ctx);
+		if (nwerr) {
+failDS:;
+			fprintf(stderr, _("%s: Could not find object %s: %s\n"),
+				progname, object_name, strnwerror(nwerr));
+			goto finished;
+		}
+		nwerr = NWDSAddConnection(ctx, conn);
+		if (nwerr) {
+			goto failDS;
+		}
+		if (!NWDSGetContext(ctx, DCK_FLAGS, &flags)) {
+			flags |= DCV_XLATE_STRINGS | DCV_TYPELESS_NAMES;
+			NWDSSetContext(ctx, DCK_FLAGS, &flags);
+		}
+		nwerr = NWDSMapNameToID(ctx, conn, object_name, &o.object_id);
+		if (nwerr) {
+			goto failDS;
+		}
+		NWDSFreeContext(ctx);
+#else
 		fprintf(stderr, _("%s: Could not find object %s: %s\n"),
 			progname, object_name, strnwerror(nwerr));
 		goto finished;
+#endif
+	} else {
+		if ((nwerr = ncp_get_bindery_object_id(conn, object_type, object_name, &o)) != 0)
+		{
+			fprintf(stderr, _("%s: Could not find object %s: %s\n"),
+				progname, object_name, strnwerror(nwerr));
+			goto finished;
+		}
 	}
 	enclen = ncp_path_to_NW_format(path, encpath, sizeof(encpath));
 	if (enclen < 0) {
@@ -194,8 +227,8 @@ main(int argc, char *argv[])
 	}
 	tstinfo.objectID = o.object_id;
 	tstinfo.objectRights = rights;
-	nwerr = ncp_ns_trustee_add(conn, NW_NS_DOS, 0x8006,
-			0xFF, 0, 0, encpath, enclen, &tstinfo, 1, ~0);
+	nwerr = ncp_ns_trustee_add(conn, NW_NS_DOS, SA_ALL,
+			NCP_DIRSTYLE_NOHANDLE, 0, 0, encpath, enclen, &tstinfo, 1, ~0);
 	if (nwerr)
 	{
 		fprintf(stderr, _("%s: Could not add trustee rights: %s\n"), 
