@@ -30,8 +30,6 @@
   
  */
 
-#include "config.h"
-
 #include <pwd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -50,10 +48,10 @@
 #include <errno.h>
 #include <ncp/nwcalls.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
-static int search_utmp(char *user, char *tty);
+static int search_utmp(const char *user, char *tty);
 
 static char *progname;
 
@@ -65,16 +63,14 @@ main(int argc, char *argv[])
 	char *mount_point;
 	uid_t uid;
 	struct passwd *pwd;
-	char tty[256];
 	char tty_path[256];
 	FILE *tty_file;
-	FILE *mtab;
-	struct mntent *mnt;
 	long err;
+	char sn[256];
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 
 	progname = argv[0];
 
@@ -101,6 +97,7 @@ main(int argc, char *argv[])
 	}
 	if (strlen(message) == 0)
 	{
+		ncp_close(conn);
 		syslog(LOG_DEBUG, _("no message"));
 		exit(0);
 	}
@@ -109,11 +106,14 @@ main(int argc, char *argv[])
 #endif
 
 	if (NWCCGetConnInfo(conn, NWCC_INFO_MOUNT_UID, sizeof(uid), &uid)) {
-		fprintf(stderr, _("%s: could not ioctl on connection: %s\n"),
+		fprintf(stderr, _("%s: could not get uid on connection: %s\n"),
 			progname, strerror(errno));
 		ncp_close(conn);
 		exit(1);
 	}
+	if (NWCCGetConnInfo(conn, NWCC_INFO_SERVER_NAME, sizeof(sn), sn)) {
+		strcpy(sn, _("<unknown>"));
+	}
 	ncp_close(conn);
 
 	if ((pwd = getpwuid(uid)) == NULL)
@@ -122,40 +122,19 @@ main(int argc, char *argv[])
 			progname, uid);
 		exit(1);
 	}
-	if ((mtab = fopen(MOUNTED, "r")) == NULL)
-	{
-		fprintf(stderr, _("%s: can't open %s\n"),
-			progname, MOUNTED);
-		exit(1);
-	}
-	while ((mnt = getmntent(mtab)) != NULL)
-	{
-		if (strcmp(mnt->mnt_dir, mount_point) == 0)
-		{
-			break;
-		}
-	}
-
-	if (mnt == NULL)
-	{
-		syslog(LOG_DEBUG, _("cannot find mtab entry\n"));
-	}
-	if (search_utmp(pwd->pw_name, tty) != 0)
+	if (search_utmp(pwd->pw_name, tty_path) != 0)
 	{
 		exit(1);
 	}
-	sprintf(tty_path, "/dev/%s", tty);
 	if ((tty_file = fopen(tty_path, "w")) == NULL)
 	{
 		fprintf(stderr, _("%s: cannot open %s: %s\n"),
 			progname, tty_path, strerror(errno));
 		exit(1);
 	}
-	fprintf(tty_file, _("\r\n\007\007\007Message from NetWare Server: %s\r\n"),
-		mnt->mnt_fsname);
-	fprintf(tty_file, _("%s\r\n"), message);
+	fprintf(tty_file, _("\r\n\007\007\007Message from NetWare Server: %s\r\n%s\r\n"),
+		sn, message);
 	fclose(tty_file);
-	fclose(mtab);
 	return 0;
 }
 
@@ -166,12 +145,10 @@ main(int argc, char *argv[])
  *     and the access time
  */
 static int
-term_chk(char *tty, int *msgsokP, time_t * atimeP, int *showerror)
+term_chk(const char *path, int *msgsokP, time_t * atimeP, int *showerror)
 {
 	struct stat s;
-	char path[MAXPATHLEN];
 
-	(void) sprintf(path, "/dev/%s", tty);
 	if (stat(path, &s) < 0)
 	{
 		if (showerror)
@@ -196,13 +173,13 @@ term_chk(char *tty, int *msgsokP, time_t * atimeP, int *showerror)
  * writing from, unless that's the only terminal with messages enabled.
  */
 static int
-search_utmp(char *user, char *tty)
+search_utmp(const char *user, char *tty)
 {
 	struct utmp u;
 	time_t bestatime, atime;
-	int ufd, nloggedttys, nttys, msgsok, user_is_me;
+	int ufd, nloggedttys, nttys, msgsok;
 
-	char atty[sizeof(u.ut_line) + 1];
+	char atty[5 + sizeof(u.ut_line) + 1];
 
 	if ((ufd = open(_PATH_UTMP, O_RDONLY)) < 0)
 	{
@@ -211,14 +188,14 @@ search_utmp(char *user, char *tty)
 	}
 	nloggedttys = nttys = 0;
 	bestatime = 0;
-	user_is_me = 0;
+	memcpy(atty, "/dev/", 5);
 	while (read(ufd, (char *) &u, sizeof(u)) == sizeof(u))
 		if (strncmp(user, u.ut_name, sizeof(u.ut_name)) == 0)
 		{
 			++nloggedttys;
 
-			(void) strncpy(atty, u.ut_line, sizeof(u.ut_line));
-			atty[sizeof(u.ut_line)] = '\0';
+			strncpy(atty + 5, u.ut_line, sizeof(u.ut_line));
+			atty[5 + sizeof(u.ut_line)] = '\0';
 
 			if (u.ut_type != USER_PROCESS)
 				continue;	/* it's not a valid entry */
