@@ -23,13 +23,12 @@
 		Initial revision.
  */
 
-#include "config.h"
-
 #include <unistd.h>
 #include <stdlib.h>
+#include <string.h>
 #include <ncp/ncplib.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -58,7 +57,7 @@ help(void)
 int
 main(int argc, char *argv[])
 {
-	struct ncp_conn_spec *spec;
+	struct ncp_conn_spec spec;
 	struct ncp_conn *conn;
 	char *server = NULL;
 	char *user_name = NULL;
@@ -76,8 +75,8 @@ main(int argc, char *argv[])
 	int opt;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 
 	progname = argv[0];
 
@@ -106,35 +105,35 @@ main(int argc, char *argv[])
 			exit(1);
 		}
 	}
-	spec = ncp_find_conn_spec(server, user_name, "",
-				  1, getuid(), &err);
+	err = ncp_find_conn_spec3(server, user_name, "",
+				  1, getuid(), 0, &spec);
 
-	if (spec == NULL)
+	if (err)
 	{
 		com_err(argv[0], err, _("trying to find server"));
 		exit(1);
 	}
 	if (!object_name)
 	{
-		object_name = spec->user;
+		object_name = spec.user;
 	} else
 	{
 		strcpy(buf_obj_name, object_name);
 		object_name = buf_obj_name;
 		str_upper(object_name);
 	}
-	spec->login_type = object_type;
+	spec.login_type = object_type;
 
 	printf(_("Changing password for user %s on server %s\n"),
-	       object_name, spec->server);
+	       object_name, spec.server);
 
-	if (object_name == spec->user)
+	if (object_name == spec.user)
 	{
 		str = getpass(_("Enter old password: "));
 	} else
 	{
 		char sx[80];
-		sprintf(sx, _("Enter password for %s: "), spec->user);
+		sprintf(sx, _("Enter password for %s: "), spec.user);
 		str = getpass(sx);
 	}
 	if (strlen(str) >= sizeof(oldpass))
@@ -169,18 +168,18 @@ main(int argc, char *argv[])
 		printf(_("You mistype the new password, try again\n"));
 		exit(1);
 	}
-	strcpy(spec->password, oldpass);
+	strcpy(spec.password, oldpass);
 
-	if ((conn = ncp_open(spec, &err)) == NULL)
+	if ((conn = ncp_open(&spec, &err)) == NULL)
 	{
 		com_err(argv[0], err, _("when trying to open connection"));
 		exit(1);
 	}
-	if (object_name != spec->user)
+	if (object_name != spec.user)
 	{
-		if (!(err = ncp_get_bindery_object_id(conn, 1, spec->user,
+		if (!(err = ncp_get_bindery_object_id(conn, 1, spec.user,
 						      &user))
-		    && !(err = ncp_login_user(conn, spec->user, oldpass)))
+		    && !(err = ncp_login_user(conn, spec.user, oldpass)))
 		{
 			*oldpass = '\0';
 		} else
