@@ -26,15 +26,14 @@
 		Added license.
  */
 
-#include "config.h"
-
+#include <stdlib.h>
 #include <ncp/nwcalls.h>
 #include <unistd.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
-void usage(void) {
+static void usage(void) {
 	printf(_(
 "usage: nwpurge [options] [directory]\n"
 "\n"
@@ -48,13 +47,13 @@ void usage(void) {
 ));
 }
 
-int subdirs = 0;
-int show = 1;
-int purge = 1;
-int files = 0;
-int failures = 0;
+static int subdirs = 0;
+static int show = 1;
+static int purge = 1;
+static int files = 0;
+static int failures = 0;
 
-void processpurge(struct ncp_conn* conn, int volume, u_int32_t directory_id) {
+static void processpurge(struct ncp_conn* conn, int volume, u_int32_t directory_id) {
 	struct ncp_deleted_file info;
 	char tmp[1024];
 
@@ -87,21 +86,17 @@ void processpurge(struct ncp_conn* conn, int volume, u_int32_t directory_id) {
 	}
 	if (show) printf("\n");
 	if (subdirs) {
-		struct nw_info_struct dir;
-		struct ncp_search_seq seq;
+		NWDIRLIST_HANDLE dh;
 
-		dir.volNumber = volume;
-		dir.dirEntNum = directory_id;
-		if (!ncp_initialize_search(conn, &dir, NW_NS_DOS, &seq)) {
-			while (!ncp_search_for_file_or_subdir2(conn,
-						SA_SUBDIR_ALL, 
-						/* RIM_ATTRIBUTES | */ RIM_DIRECTORY,
-						&seq,
-						&dir)) {
-				processpurge(conn, dir.volNumber, dir.DosDirNum);
+		if (!ncp_ns_search_init(conn, NW_NS_DOS, SA_SUBDIR_ALL, NCP_DIRSTYLE_DIRBASE, volume, directory_id,
+				NULL, 0, 0, "\xFF*", 2, RIM_DIRECTORY, &dh)) {
+			struct nw_info_struct2 dir;
+			
+			while (!ncp_ns_search_next(dh, &dir, sizeof(dir))) {
+				processpurge(conn, dir.Directory.volNumber, dir.Directory.DosDirNum);
 			}
+			ncp_ns_search_end(dh);
 		}
-
 	}
 }
 
@@ -113,8 +108,8 @@ int main(int argc, char* argv[]) {
 	int c;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	while ((c = getopt(argc, argv, "ahls")) != -1) {
 		switch (c) {
