@@ -169,6 +169,10 @@ static void print_value(int format, const char* title, const char* units, u_int6
 	}
 }
 
+static inline size_t my_strftime(char *s, size_t max, const char *fmt, const struct tm *tm) {
+	return strftime(s, max, fmt, tm);
+}
+
 int
 main(int argc, char **argv)
 {
@@ -350,7 +354,7 @@ main(int argc, char **argv)
 			struct tm* tm;
 			
 			tm = localtime(&login_time);
-			strftime(text_login_time, sizeof(text_login_time), "%c", tm);
+			my_strftime(text_login_time, sizeof(text_login_time), "%c", tm);
 			printf("%s\n", text_login_time);
 		}
 		if (print_file) {
